BOOT:
        newXS("Bio::Emboss::ajAcdDebug", XS_Bio__Emboss_ajAcdDebug, file);
        newXS("Bio::Emboss::ajAcdDebugIsSet", XS_Bio__Emboss_ajAcdDebugIsSet, file);
        newXS("Bio::Emboss::ajAcdExit", XS_Bio__Emboss_ajAcdExit, file);
        newXS("Bio::Emboss::ajAcdFilter", XS_Bio__Emboss_ajAcdFilter, file);
        newXS("Bio::Emboss::ajAcdGetAlign", XS_Bio__Emboss_ajAcdGetAlign, file);
        newXS("Bio::Emboss::ajAcdGetArray", XS_Bio__Emboss_ajAcdGetArray, file);
        newXS("Bio::Emboss::ajAcdGetBool", XS_Bio__Emboss_ajAcdGetBool, file);
        newXS("Bio::Emboss::ajAcdGetCodon", XS_Bio__Emboss_ajAcdGetCodon, file);
        newXS("Bio::Emboss::ajAcdGetDatafile", XS_Bio__Emboss_ajAcdGetDatafile, file);
        newXS("Bio::Emboss::ajAcdGetDirlist", XS_Bio__Emboss_ajAcdGetDirlist, file);
        newXS("Bio::Emboss::ajAcdGetFeat", XS_Bio__Emboss_ajAcdGetFeat, file);
        newXS("Bio::Emboss::ajAcdGetFeatout", XS_Bio__Emboss_ajAcdGetFeatout, file);
        newXS("Bio::Emboss::ajAcdGetFilelist", XS_Bio__Emboss_ajAcdGetFilelist, file);
        newXS("Bio::Emboss::ajAcdGetFloat", XS_Bio__Emboss_ajAcdGetFloat, file);
        newXS("Bio::Emboss::ajAcdGetGraph", XS_Bio__Emboss_ajAcdGetGraph, file);
        newXS("Bio::Emboss::ajAcdGetGraphxy", XS_Bio__Emboss_ajAcdGetGraphxy, file);
        newXS("Bio::Emboss::ajAcdGetInfile", XS_Bio__Emboss_ajAcdGetInfile, file);
        newXS("Bio::Emboss::ajAcdGetInt", XS_Bio__Emboss_ajAcdGetInt, file);
        newXS("Bio::Emboss::ajAcdGetList", XS_Bio__Emboss_ajAcdGetList, file);
        newXS("Bio::Emboss::ajAcdGetListI", XS_Bio__Emboss_ajAcdGetListI, file);
        newXS("Bio::Emboss::ajAcdGetMatrix", XS_Bio__Emboss_ajAcdGetMatrix, file);
        newXS("Bio::Emboss::ajAcdGetMatrixf", XS_Bio__Emboss_ajAcdGetMatrixf, file);
        newXS("Bio::Emboss::ajAcdGetOutfile", XS_Bio__Emboss_ajAcdGetOutfile, file);
        newXS("Bio::Emboss::ajAcdGetCpdb", XS_Bio__Emboss_ajAcdGetCpdb, file);
        newXS("Bio::Emboss::ajAcdGetRange", XS_Bio__Emboss_ajAcdGetRange, file);
        newXS("Bio::Emboss::ajAcdGetRegexp", XS_Bio__Emboss_ajAcdGetRegexp, file);
        newXS("Bio::Emboss::ajAcdGetReport", XS_Bio__Emboss_ajAcdGetReport, file);
        newXS("Bio::Emboss::ajAcdGetScop", XS_Bio__Emboss_ajAcdGetScop, file);
        newXS("Bio::Emboss::ajAcdGetSelect", XS_Bio__Emboss_ajAcdGetSelect, file);
        newXS("Bio::Emboss::ajAcdGetSelectI", XS_Bio__Emboss_ajAcdGetSelectI, file);
        newXS("Bio::Emboss::ajAcdGetSeq", XS_Bio__Emboss_ajAcdGetSeq, file);
        newXS("Bio::Emboss::ajAcdGetSeqall", XS_Bio__Emboss_ajAcdGetSeqall, file);
        newXS("Bio::Emboss::ajAcdGetSeqout", XS_Bio__Emboss_ajAcdGetSeqout, file);
        newXS("Bio::Emboss::ajAcdGetSeqoutall", XS_Bio__Emboss_ajAcdGetSeqoutall, file);
        newXS("Bio::Emboss::ajAcdGetSeqoutset", XS_Bio__Emboss_ajAcdGetSeqoutset, file);
        newXS("Bio::Emboss::ajAcdGetSeqset", XS_Bio__Emboss_ajAcdGetSeqset, file);
        newXS("Bio::Emboss::ajAcdGetString", XS_Bio__Emboss_ajAcdGetString, file);
        newXS("Bio::Emboss::ajAcdPrintType", XS_Bio__Emboss_ajAcdPrintType, file);
        newXS("Bio::Emboss::ajAcdProgram", XS_Bio__Emboss_ajAcdProgram, file);
        newXS("Bio::Emboss::ajAcdProgramS", XS_Bio__Emboss_ajAcdProgramS, file);
        newXS("Bio::Emboss::ajAcdStdout", XS_Bio__Emboss_ajAcdStdout, file);
        newXS("Bio::Emboss::ajAcdValue", XS_Bio__Emboss_ajAcdValue, file);
        newXS("Bio::Emboss::ajFeatIsChild", XS_Bio__Emboss_ajFeatIsChild, file);
        newXS("Bio::Emboss::ajFeatIsCompMult", XS_Bio__Emboss_ajFeatIsCompMult, file);
        newXS("Bio::Emboss::ajFeatCopy", XS_Bio__Emboss_ajFeatCopy, file);
        newXS("Bio::Emboss::ajFeatDel", XS_Bio__Emboss_ajFeatDel, file);
        newXS("Bio::Emboss::ajFeatExit", XS_Bio__Emboss_ajFeatExit, file);
        newXS("Bio::Emboss::ajFeatGetEnd", XS_Bio__Emboss_ajFeatGetEnd, file);
        newXS("Bio::Emboss::ajFeatGetForward", XS_Bio__Emboss_ajFeatGetForward, file);
        newXS("Bio::Emboss::ajFeatGetFrame", XS_Bio__Emboss_ajFeatGetFrame, file);
        newXS("Bio::Emboss::ajFeatGetLocs", XS_Bio__Emboss_ajFeatGetLocs, file);
        newXS("Bio::Emboss::ajFeatGetNote", XS_Bio__Emboss_ajFeatGetNote, file);
        newXS("Bio::Emboss::ajFeatGetNoteI", XS_Bio__Emboss_ajFeatGetNoteI, file);
        newXS("Bio::Emboss::ajFeatGetStart", XS_Bio__Emboss_ajFeatGetStart, file);
        newXS("Bio::Emboss::ajFeatGetTag", XS_Bio__Emboss_ajFeatGetTag, file);
        newXS("Bio::Emboss::ajFeatGetType", XS_Bio__Emboss_ajFeatGetType, file);
        newXS("Bio::Emboss::ajFeatGetTrans", XS_Bio__Emboss_ajFeatGetTrans, file);
        newXS("Bio::Emboss::ajFeatIsLocal", XS_Bio__Emboss_ajFeatIsLocal, file);
        newXS("Bio::Emboss::ajFeatIsLocalRange", XS_Bio__Emboss_ajFeatIsLocalRange, file);
        newXS("Bio::Emboss::ajFeatIsMultiple", XS_Bio__Emboss_ajFeatIsMultiple, file);
        newXS("Bio::Emboss::ajFeatLocToSeq", XS_Bio__Emboss_ajFeatLocToSeq, file);
        newXS("Bio::Emboss::ajFeatNew", XS_Bio__Emboss_ajFeatNew, file);
        newXS("Bio::Emboss::ajFeatNewII", XS_Bio__Emboss_ajFeatNewII, file);
        newXS("Bio::Emboss::ajFeatNewProt", XS_Bio__Emboss_ajFeatNewProt, file);
        newXS("Bio::Emboss::ajFeatRead", XS_Bio__Emboss_ajFeatRead, file);
#ifdef HAVE_EMBOSS_2_7_0
        newXS("Bio::Emboss::ajFeatReverse", XS_Bio__Emboss_ajFeatReverse, file);
#else
        newXS("Bio::Emboss::ajFeatReverse", XS_Bio__Emboss_ajFeatReverse, file);
#endif
        newXS("Bio::Emboss::ajFeatSetDesc", XS_Bio__Emboss_ajFeatSetDesc, file);
        newXS("Bio::Emboss::ajFeatSetDescApp", XS_Bio__Emboss_ajFeatSetDescApp, file);
        newXS("Bio::Emboss::ajFeatSortByEnd", XS_Bio__Emboss_ajFeatSortByEnd, file);
        newXS("Bio::Emboss::ajFeatSortByStart", XS_Bio__Emboss_ajFeatSortByStart, file);
        newXS("Bio::Emboss::ajFeatSortByType", XS_Bio__Emboss_ajFeatSortByType, file);
        newXS("Bio::Emboss::ajFeattableAdd", XS_Bio__Emboss_ajFeattableAdd, file);
        newXS("Bio::Emboss::ajFeattableBegin", XS_Bio__Emboss_ajFeattableBegin, file);
        newXS("Bio::Emboss::ajFeattableClear", XS_Bio__Emboss_ajFeattableClear, file);
        newXS("Bio::Emboss::ajFeattableCopy", XS_Bio__Emboss_ajFeattableCopy, file);
        newXS("Bio::Emboss::ajFeattableDel", XS_Bio__Emboss_ajFeattableDel, file);
        newXS("Bio::Emboss::ajFeattableEnd", XS_Bio__Emboss_ajFeattableEnd, file);
        newXS("Bio::Emboss::ajFeattableGetName", XS_Bio__Emboss_ajFeattableGetName, file);
        newXS("Bio::Emboss::ajFeattableIsNuc", XS_Bio__Emboss_ajFeattableIsNuc, file);
        newXS("Bio::Emboss::ajFeattableIsProt", XS_Bio__Emboss_ajFeattableIsProt, file);
        newXS("Bio::Emboss::ajFeattableLen", XS_Bio__Emboss_ajFeattableLen, file);
        newXS("Bio::Emboss::ajFeattableNew", XS_Bio__Emboss_ajFeattableNew, file);
        newXS("Bio::Emboss::ajFeattableNewDna", XS_Bio__Emboss_ajFeattableNewDna, file);
        newXS("Bio::Emboss::ajFeattableNewProt", XS_Bio__Emboss_ajFeattableNewProt, file);
        newXS("Bio::Emboss::ajFeattableNewSeq", XS_Bio__Emboss_ajFeattableNewSeq, file);
        newXS("Bio::Emboss::ajFeattablePos", XS_Bio__Emboss_ajFeattablePos, file);
        newXS("Bio::Emboss::ajFeattablePosI", XS_Bio__Emboss_ajFeattablePosI, file);
        newXS("Bio::Emboss::ajFeattablePosII", XS_Bio__Emboss_ajFeattablePosII, file);
        newXS("Bio::Emboss::ajFeattableReverse", XS_Bio__Emboss_ajFeattableReverse, file);
        newXS("Bio::Emboss::ajFeattableSetDna", XS_Bio__Emboss_ajFeattableSetDna, file);
        newXS("Bio::Emboss::ajFeattableSetProt", XS_Bio__Emboss_ajFeattableSetProt, file);
        newXS("Bio::Emboss::ajFeattableSetRange", XS_Bio__Emboss_ajFeattableSetRange, file);
        newXS("Bio::Emboss::ajFeattableSize", XS_Bio__Emboss_ajFeattableSize, file);
        newXS("Bio::Emboss::ajFeattableTrace", XS_Bio__Emboss_ajFeattableTrace, file);
        newXS("Bio::Emboss::ajFeattableWriteDdbj", XS_Bio__Emboss_ajFeattableWriteDdbj, file);
        newXS("Bio::Emboss::ajFeattableWriteEmbl", XS_Bio__Emboss_ajFeattableWriteEmbl, file);
        newXS("Bio::Emboss::ajFeattableWriteGenbank", XS_Bio__Emboss_ajFeattableWriteGenbank, file);
        newXS("Bio::Emboss::ajFeattableWriteGff", XS_Bio__Emboss_ajFeattableWriteGff, file);
        newXS("Bio::Emboss::ajFeattableWritePir", XS_Bio__Emboss_ajFeattableWritePir, file);
        newXS("Bio::Emboss::ajFeattableWriteSwiss", XS_Bio__Emboss_ajFeattableWriteSwiss, file);
        newXS("Bio::Emboss::ajFeattabInClear", XS_Bio__Emboss_ajFeattabInClear, file);
        newXS("Bio::Emboss::ajFeattabInDel", XS_Bio__Emboss_ajFeattabInDel, file);
        newXS("Bio::Emboss::ajFeattabInNew", XS_Bio__Emboss_ajFeattabInNew, file);
        newXS("Bio::Emboss::ajFeattabInNewSS", XS_Bio__Emboss_ajFeattabInNewSS, file);
        newXS("Bio::Emboss::ajFeattabInNewSSF", XS_Bio__Emboss_ajFeattabInNewSSF, file);
        newXS("Bio::Emboss::ajFeattabOutDel", XS_Bio__Emboss_ajFeattabOutDel, file);
        newXS("Bio::Emboss::ajFeattabOutFile", XS_Bio__Emboss_ajFeattabOutFile, file);
        newXS("Bio::Emboss::ajFeattabOutFilename", XS_Bio__Emboss_ajFeattabOutFilename, file);
        newXS("Bio::Emboss::ajFeattabOutIsOpen", XS_Bio__Emboss_ajFeattabOutIsOpen, file);
        newXS("Bio::Emboss::ajFeattabOutNew", XS_Bio__Emboss_ajFeattabOutNew, file);
        newXS("Bio::Emboss::ajFeattabOutNewSSF", XS_Bio__Emboss_ajFeattabOutNewSSF, file);
        newXS("Bio::Emboss::ajFeattabOutOpen", XS_Bio__Emboss_ajFeattabOutOpen, file);
        newXS("Bio::Emboss::ajFeattabOutSet", XS_Bio__Emboss_ajFeattabOutSet, file);
        newXS("Bio::Emboss::ajFeatTagAdd", XS_Bio__Emboss_ajFeatTagAdd, file);
        newXS("Bio::Emboss::ajFeatTagAddC", XS_Bio__Emboss_ajFeatTagAddC, file);
        newXS("Bio::Emboss::ajFeatTagAddCC", XS_Bio__Emboss_ajFeatTagAddCC, file);
        newXS("Bio::Emboss::ajFeatTagIter", XS_Bio__Emboss_ajFeatTagIter, file);
#ifdef HAVE_EMBOSS_2_7_0
        newXS("Bio::Emboss::ajFeatTagSet", XS_Bio__Emboss_ajFeatTagSet, file);
        newXS("Bio::Emboss::ajFeatTagSetC", XS_Bio__Emboss_ajFeatTagSetC, file);
#else
        newXS("Bio::Emboss::ajFeatTagSet", XS_Bio__Emboss_ajFeatTagSet, file);
        newXS("Bio::Emboss::ajFeatTagSetC", XS_Bio__Emboss_ajFeatTagSetC, file);
#endif
        newXS("Bio::Emboss::ajFeatTagTrace", XS_Bio__Emboss_ajFeatTagTrace, file);
        newXS("Bio::Emboss::ajFeatTagval", XS_Bio__Emboss_ajFeatTagval, file);
        newXS("Bio::Emboss::ajFeatTest", XS_Bio__Emboss_ajFeatTest, file);
        newXS("Bio::Emboss::ajFeatTrace", XS_Bio__Emboss_ajFeatTrace, file);
        newXS("Bio::Emboss::ajFeatUfoRead", XS_Bio__Emboss_ajFeatUfoRead, file);
        newXS("Bio::Emboss::ajFeatUfoWrite", XS_Bio__Emboss_ajFeatUfoWrite, file);
        newXS("Bio::Emboss::ajFeatWrite", XS_Bio__Emboss_ajFeatWrite, file);
        newXS("Bio::Emboss::ajFileBuffClear", XS_Bio__Emboss_ajFileBuffClear, file);
        newXS("Bio::Emboss::ajFileBuffDel", XS_Bio__Emboss_ajFileBuffDel, file);
        newXS("Bio::Emboss::ajFileBuffEmpty", XS_Bio__Emboss_ajFileBuffEmpty, file);
        newXS("Bio::Emboss::ajFileBuffEnd", XS_Bio__Emboss_ajFileBuffEnd, file);
        newXS("Bio::Emboss::ajFileBuffEof", XS_Bio__Emboss_ajFileBuffEof, file);
        newXS("Bio::Emboss::ajFileBuffFile", XS_Bio__Emboss_ajFileBuffFile, file);
        newXS("Bio::Emboss::ajFileBuffFix", XS_Bio__Emboss_ajFileBuffFix, file);
        newXS("Bio::Emboss::ajFileBuffFp", XS_Bio__Emboss_ajFileBuffFp, file);
        newXS("Bio::Emboss::ajFileBuffFreeClear", XS_Bio__Emboss_ajFileBuffFreeClear, file);
        newXS("Bio::Emboss::ajFileBuffGet", XS_Bio__Emboss_ajFileBuffGet, file);
        newXS("Bio::Emboss::ajFileBuffGetL", XS_Bio__Emboss_ajFileBuffGetL, file);
        newXS("Bio::Emboss::ajFileBuffGetStore", XS_Bio__Emboss_ajFileBuffGetStore, file);
        newXS("Bio::Emboss::ajFileBuffLoad", XS_Bio__Emboss_ajFileBuffLoad, file);
        newXS("Bio::Emboss::ajFileBuffLoadC", XS_Bio__Emboss_ajFileBuffLoadC, file);
        newXS("Bio::Emboss::ajFileBuffLoadS", XS_Bio__Emboss_ajFileBuffLoadS, file);
        newXS("Bio::Emboss::ajFileBuffNew", XS_Bio__Emboss_ajFileBuffNew, file);
        newXS("Bio::Emboss::ajFileBuffNewDC", XS_Bio__Emboss_ajFileBuffNewDC, file);
        newXS("Bio::Emboss::ajFileBuffNewDF", XS_Bio__Emboss_ajFileBuffNewDF, file);
        newXS("Bio::Emboss::ajFileBuffNewDW", XS_Bio__Emboss_ajFileBuffNewDW, file);
        newXS("Bio::Emboss::ajFileBuffNewFile", XS_Bio__Emboss_ajFileBuffNewFile, file);
        newXS("Bio::Emboss::ajFileBuffNewIn", XS_Bio__Emboss_ajFileBuffNewIn, file);
        newXS("Bio::Emboss::ajFileBuffNewInList", XS_Bio__Emboss_ajFileBuffNewInList, file);
        newXS("Bio::Emboss::ajFileBuffNewS", XS_Bio__Emboss_ajFileBuffNewS, file);
        newXS("Bio::Emboss::ajFileBuffNobuff", XS_Bio__Emboss_ajFileBuffNobuff, file);
        newXS("Bio::Emboss::ajFileBuffReset", XS_Bio__Emboss_ajFileBuffReset, file);
        newXS("Bio::Emboss::ajFileBuffResetPos", XS_Bio__Emboss_ajFileBuffResetPos, file);
        newXS("Bio::Emboss::ajFileBuffSetFile", XS_Bio__Emboss_ajFileBuffSetFile, file);
        newXS("Bio::Emboss::ajFileBuffSize", XS_Bio__Emboss_ajFileBuffSize, file);
        newXS("Bio::Emboss::ajFileBuffStripHtml", XS_Bio__Emboss_ajFileBuffStripHtml, file);
        newXS("Bio::Emboss::ajFileBuffStripSrs", XS_Bio__Emboss_ajFileBuffStripSrs, file);
        newXS("Bio::Emboss::ajFileBuffTrace", XS_Bio__Emboss_ajFileBuffTrace, file);
        newXS("Bio::Emboss::ajFileBuffTraceFull", XS_Bio__Emboss_ajFileBuffTraceFull, file);
        newXS("Bio::Emboss::ajFileClose", XS_Bio__Emboss_ajFileClose, file);
        newXS("Bio::Emboss::ajFileDataDirNew", XS_Bio__Emboss_ajFileDataDirNew, file);
        newXS("Bio::Emboss::ajFileDataDirNewC", XS_Bio__Emboss_ajFileDataDirNewC, file);
        newXS("Bio::Emboss::ajFileDataNew", XS_Bio__Emboss_ajFileDataNew, file);
        newXS("Bio::Emboss::ajFileDataNewC", XS_Bio__Emboss_ajFileDataNewC, file);
        newXS("Bio::Emboss::ajFileDataNewWrite", XS_Bio__Emboss_ajFileDataNewWrite, file);
        newXS("Bio::Emboss::ajFileDir", XS_Bio__Emboss_ajFileDir, file);
        newXS("Bio::Emboss::ajFileDirFix", XS_Bio__Emboss_ajFileDirFix, file);
        newXS("Bio::Emboss::ajFileDirUp", XS_Bio__Emboss_ajFileDirUp, file);
        newXS("Bio::Emboss::ajFileDirPath", XS_Bio__Emboss_ajFileDirPath, file);
        newXS("Bio::Emboss::ajFileDirTrim", XS_Bio__Emboss_ajFileDirTrim, file);
        newXS("Bio::Emboss::ajFileExit", XS_Bio__Emboss_ajFileExit, file);
        newXS("Bio::Emboss::ajFileFileList", XS_Bio__Emboss_ajFileFileList, file);
        newXS("Bio::Emboss::ajFileFp", XS_Bio__Emboss_ajFileFp, file);
        newXS("Bio::Emboss::ajFileGetwd", XS_Bio__Emboss_ajFileGetwd, file);
        newXS("Bio::Emboss::ajFileGetName", XS_Bio__Emboss_ajFileGetName, file);
        newXS("Bio::Emboss::ajFileGets", XS_Bio__Emboss_ajFileGets, file);
        newXS("Bio::Emboss::ajFileGetsL", XS_Bio__Emboss_ajFileGetsL, file);
        newXS("Bio::Emboss::ajFileGetsTrim", XS_Bio__Emboss_ajFileGetsTrim, file);
        newXS("Bio::Emboss::ajFileGetsTrimL", XS_Bio__Emboss_ajFileGetsTrimL, file);
        newXS("Bio::Emboss::ajFileLength", XS_Bio__Emboss_ajFileLength, file);
        newXS("Bio::Emboss::ajFileName", XS_Bio__Emboss_ajFileName, file);
        newXS("Bio::Emboss::ajFileNameDirSet", XS_Bio__Emboss_ajFileNameDirSet, file);
        newXS("Bio::Emboss::ajFileNameDirSetC", XS_Bio__Emboss_ajFileNameDirSetC, file);
        newXS("Bio::Emboss::ajFileNameExt", XS_Bio__Emboss_ajFileNameExt, file);
        newXS("Bio::Emboss::ajFileNameExtC", XS_Bio__Emboss_ajFileNameExtC, file);
        newXS("Bio::Emboss::ajFileNameShorten", XS_Bio__Emboss_ajFileNameShorten, file);
        newXS("Bio::Emboss::ajFileNameTrim", XS_Bio__Emboss_ajFileNameTrim, file);
        newXS("Bio::Emboss::ajFileNew", XS_Bio__Emboss_ajFileNew, file);
        newXS("Bio::Emboss::ajFileNewApp", XS_Bio__Emboss_ajFileNewApp, file);
        newXS("Bio::Emboss::ajFileNewDC", XS_Bio__Emboss_ajFileNewDC, file);
        newXS("Bio::Emboss::ajFileNewDF", XS_Bio__Emboss_ajFileNewDF, file);
        newXS("Bio::Emboss::ajFileNewDW", XS_Bio__Emboss_ajFileNewDW, file);
        newXS("Bio::Emboss::ajFileNewF", XS_Bio__Emboss_ajFileNewF, file);
        newXS("Bio::Emboss::ajFileNewIn", XS_Bio__Emboss_ajFileNewIn, file);
        newXS("Bio::Emboss::ajFileNewInC", XS_Bio__Emboss_ajFileNewInC, file);
        newXS("Bio::Emboss::ajFileNewInPipe", XS_Bio__Emboss_ajFileNewInPipe, file);
        newXS("Bio::Emboss::ajFileNewInList", XS_Bio__Emboss_ajFileNewInList, file);
        newXS("Bio::Emboss::ajFileNewOut", XS_Bio__Emboss_ajFileNewOut, file);
        newXS("Bio::Emboss::ajFileNewOutD", XS_Bio__Emboss_ajFileNewOutD, file);
        newXS("Bio::Emboss::ajFileOutHeader", XS_Bio__Emboss_ajFileOutHeader, file);
        newXS("Bio::Emboss::ajFileOutClose", XS_Bio__Emboss_ajFileOutClose, file);
        newXS("Bio::Emboss::ajFileNext", XS_Bio__Emboss_ajFileNext, file);
        newXS("Bio::Emboss::ajFileRead", XS_Bio__Emboss_ajFileRead, file);
        newXS("Bio::Emboss::ajFileReopen", XS_Bio__Emboss_ajFileReopen, file);
        newXS("Bio::Emboss::ajFileReadLine", XS_Bio__Emboss_ajFileReadLine, file);
        newXS("Bio::Emboss::ajFileReadUint", XS_Bio__Emboss_ajFileReadUint, file);
        newXS("Bio::Emboss::ajFileScan", XS_Bio__Emboss_ajFileScan, file);
        newXS("Bio::Emboss::ajFileSeek", XS_Bio__Emboss_ajFileSeek, file);
        newXS("Bio::Emboss::ajFileStat", XS_Bio__Emboss_ajFileStat, file);
        newXS("Bio::Emboss::ajFileStderr", XS_Bio__Emboss_ajFileStderr, file);
        newXS("Bio::Emboss::ajFileStdin", XS_Bio__Emboss_ajFileStdin, file);
        newXS("Bio::Emboss::ajFileStdout", XS_Bio__Emboss_ajFileStdout, file);
        newXS("Bio::Emboss::ajFileTell", XS_Bio__Emboss_ajFileTell, file);
        newXS("Bio::Emboss::ajFileTempName", XS_Bio__Emboss_ajFileTempName, file);
        newXS("Bio::Emboss::ajFileTestSkip", XS_Bio__Emboss_ajFileTestSkip, file);
        newXS("Bio::Emboss::ajFileTrace", XS_Bio__Emboss_ajFileTrace, file);
        newXS("Bio::Emboss::ajFileUnbuffer", XS_Bio__Emboss_ajFileUnbuffer, file);
        newXS("Bio::Emboss::ajFileWrite", XS_Bio__Emboss_ajFileWrite, file);
        newXS("Bio::Emboss::ajFileWriteByte", XS_Bio__Emboss_ajFileWriteByte, file);
        newXS("Bio::Emboss::ajFileWriteChar", XS_Bio__Emboss_ajFileWriteChar, file);
        newXS("Bio::Emboss::ajFileWriteInt2", XS_Bio__Emboss_ajFileWriteInt2, file);
        newXS("Bio::Emboss::ajFileWriteInt4", XS_Bio__Emboss_ajFileWriteInt4, file);
        newXS("Bio::Emboss::ajFileWriteInt8", XS_Bio__Emboss_ajFileWriteInt8, file);
        newXS("Bio::Emboss::ajFileWriteStr", XS_Bio__Emboss_ajFileWriteStr, file);
        newXS("Bio::Emboss::ajGraphBox", XS_Bio__Emboss_ajGraphBox, file);
        newXS("Bio::Emboss::ajGraphBoxFill", XS_Bio__Emboss_ajGraphBoxFill, file);
        newXS("Bio::Emboss::ajGraphCheckColour", XS_Bio__Emboss_ajGraphCheckColour, file);
        newXS("Bio::Emboss::ajGraphCircle", XS_Bio__Emboss_ajGraphCircle, file);
        newXS("Bio::Emboss::ajGraphClose", XS_Bio__Emboss_ajGraphClose, file);
        newXS("Bio::Emboss::ajGraphCloseWin", XS_Bio__Emboss_ajGraphCloseWin, file);
        newXS("Bio::Emboss::ajGraphColourBack", XS_Bio__Emboss_ajGraphColourBack, file);
        newXS("Bio::Emboss::ajGraphColourFore", XS_Bio__Emboss_ajGraphColourFore, file);
        newXS("Bio::Emboss::ajGraphDataDel", XS_Bio__Emboss_ajGraphDataDel, file);
        newXS("Bio::Emboss::ajGraphDataObjAddLine", XS_Bio__Emboss_ajGraphDataObjAddLine, file);
        newXS("Bio::Emboss::ajGraphDataObjAddRect", XS_Bio__Emboss_ajGraphDataObjAddRect, file);
        newXS("Bio::Emboss::ajGraphDataObjAddText", XS_Bio__Emboss_ajGraphDataObjAddText, file);
        newXS("Bio::Emboss::ajGraphDataxySetMaxMin", XS_Bio__Emboss_ajGraphDataxySetMaxMin, file);
        newXS("Bio::Emboss::ajGraphDataxyMaxMin", XS_Bio__Emboss_ajGraphDataxyMaxMin, file);
        newXS("Bio::Emboss::ajGraphDataxySetMaxima", XS_Bio__Emboss_ajGraphDataxySetMaxima, file);
        newXS("Bio::Emboss::ajGraphDataxySetTypeC", XS_Bio__Emboss_ajGraphDataxySetTypeC, file);
        newXS("Bio::Emboss::ajGraphDia", XS_Bio__Emboss_ajGraphDia, file);
        newXS("Bio::Emboss::ajGraphDiaFill", XS_Bio__Emboss_ajGraphDiaFill, file);
        newXS("Bio::Emboss::ajGraphDots", XS_Bio__Emboss_ajGraphDots, file);
        newXS("Bio::Emboss::ajGraphDumpDevices", XS_Bio__Emboss_ajGraphDumpDevices, file);
        newXS("Bio::Emboss::ajGraphGetCharSize", XS_Bio__Emboss_ajGraphGetCharSize, file);
        newXS("Bio::Emboss::ajGraphGetColour", XS_Bio__Emboss_ajGraphGetColour, file);
        newXS("Bio::Emboss::ajGraphGetOut", XS_Bio__Emboss_ajGraphGetOut, file);
        newXS("Bio::Emboss::ajGraphHoriBars", XS_Bio__Emboss_ajGraphHoriBars, file);
        newXS("Bio::Emboss::ajGraphInfo", XS_Bio__Emboss_ajGraphInfo, file);
        newXS("Bio::Emboss::ajGraphInitSeq", XS_Bio__Emboss_ajGraphInitSeq, file);
        newXS("Bio::Emboss::ajGraphLabel", XS_Bio__Emboss_ajGraphLabel, file);
        newXS("Bio::Emboss::ajGraphLabelYRight", XS_Bio__Emboss_ajGraphLabelYRight, file);
        newXS("Bio::Emboss::ajGraphLine", XS_Bio__Emboss_ajGraphLine, file);
        newXS("Bio::Emboss::ajGraphLines", XS_Bio__Emboss_ajGraphLines, file);
        newXS("Bio::Emboss::ajGraphNew", XS_Bio__Emboss_ajGraphNew, file);
        newXS("Bio::Emboss::ajGraphNewPage", XS_Bio__Emboss_ajGraphNewPage, file);
        newXS("Bio::Emboss::ajGraphObjAddLine", XS_Bio__Emboss_ajGraphObjAddLine, file);
        newXS("Bio::Emboss::ajGraphObjAddRect", XS_Bio__Emboss_ajGraphObjAddRect, file);
        newXS("Bio::Emboss::ajGraphObjAddText", XS_Bio__Emboss_ajGraphObjAddText, file);
        newXS("Bio::Emboss::ajGraphObjDel", XS_Bio__Emboss_ajGraphObjDel, file);
        newXS("Bio::Emboss::ajGraphDataObjDel", XS_Bio__Emboss_ajGraphDataObjDel, file);
        newXS("Bio::Emboss::ajGraphOpen", XS_Bio__Emboss_ajGraphOpen, file);
        newXS("Bio::Emboss::ajGraphOpenPlot", XS_Bio__Emboss_ajGraphOpenPlot, file);
        newXS("Bio::Emboss::ajGraphOpenWin", XS_Bio__Emboss_ajGraphOpenWin, file);
        newXS("Bio::Emboss::ajGraphPlenv", XS_Bio__Emboss_ajGraphPlenv, file);
        newXS("Bio::Emboss::ajGraphPoly", XS_Bio__Emboss_ajGraphPoly, file);
        newXS("Bio::Emboss::ajGraphPolyFill", XS_Bio__Emboss_ajGraphPolyFill, file);
        newXS("Bio::Emboss::ajGraphPrintType", XS_Bio__Emboss_ajGraphPrintType, file);
        newXS("Bio::Emboss::ajGraphRect", XS_Bio__Emboss_ajGraphRect, file);
        newXS("Bio::Emboss::ajGraphRectFill", XS_Bio__Emboss_ajGraphRectFill, file);
        newXS("Bio::Emboss::ajGraphSet", XS_Bio__Emboss_ajGraphSet, file);
        newXS("Bio::Emboss::ajGraphSetDevice", XS_Bio__Emboss_ajGraphSetDevice, file);
        newXS("Bio::Emboss::ajGraphSetCharSize", XS_Bio__Emboss_ajGraphSetCharSize, file);
        newXS("Bio::Emboss::ajGraphSetBackBlack", XS_Bio__Emboss_ajGraphSetBackBlack, file);
        newXS("Bio::Emboss::ajGraphSetBackWhite", XS_Bio__Emboss_ajGraphSetBackWhite, file);
        newXS("Bio::Emboss::ajGraphSetPenWidth", XS_Bio__Emboss_ajGraphSetPenWidth, file);
        newXS("Bio::Emboss::ajGraphSetFillPat", XS_Bio__Emboss_ajGraphSetFillPat, file);
        newXS("Bio::Emboss::ajGraphSetFore", XS_Bio__Emboss_ajGraphSetFore, file);
        newXS("Bio::Emboss::ajGraphSetLineStyle", XS_Bio__Emboss_ajGraphSetLineStyle, file);
        newXS("Bio::Emboss::ajGraphSetMulti", XS_Bio__Emboss_ajGraphSetMulti, file);
        newXS("Bio::Emboss::ajGraphSetName", XS_Bio__Emboss_ajGraphSetName, file);
        newXS("Bio::Emboss::ajGraphSetOri", XS_Bio__Emboss_ajGraphSetOri, file);
        newXS("Bio::Emboss::ajGraphSymbols", XS_Bio__Emboss_ajGraphSymbols, file);
        newXS("Bio::Emboss::ajGraphText", XS_Bio__Emboss_ajGraphText, file);
        newXS("Bio::Emboss::ajGraphTextEnd", XS_Bio__Emboss_ajGraphTextEnd, file);
        newXS("Bio::Emboss::ajGraphTextMid", XS_Bio__Emboss_ajGraphTextMid, file);
        newXS("Bio::Emboss::ajGraphTextLine", XS_Bio__Emboss_ajGraphTextLine, file);
        newXS("Bio::Emboss::ajGraphTextStart", XS_Bio__Emboss_ajGraphTextStart, file);
        newXS("Bio::Emboss::ajGraphTrace", XS_Bio__Emboss_ajGraphTrace, file);
        newXS("Bio::Emboss::ajGraphTraceInt", XS_Bio__Emboss_ajGraphTraceInt, file);
        newXS("Bio::Emboss::ajGraphTri", XS_Bio__Emboss_ajGraphTri, file);
        newXS("Bio::Emboss::ajGraphTriFill", XS_Bio__Emboss_ajGraphTriFill, file);
        newXS("Bio::Emboss::ajGraphUnused", XS_Bio__Emboss_ajGraphUnused, file);
        newXS("Bio::Emboss::ajGraphVertBars", XS_Bio__Emboss_ajGraphVertBars, file);
        newXS("Bio::Emboss::ajGraphxyAddDataCalcPtr", XS_Bio__Emboss_ajGraphxyAddDataCalcPtr, file);
        newXS("Bio::Emboss::ajGraphxyAddDataPtrPtr", XS_Bio__Emboss_ajGraphxyAddDataPtrPtr, file);
        newXS("Bio::Emboss::ajGraphxyAddGraph", XS_Bio__Emboss_ajGraphxyAddGraph, file);
        newXS("Bio::Emboss::ajGraphxyReplaceGraph", XS_Bio__Emboss_ajGraphxyReplaceGraph, file);
        newXS("Bio::Emboss::ajGraphxyDataNew", XS_Bio__Emboss_ajGraphxyDataNew, file);
        newXS("Bio::Emboss::ajGraphxyDataNewI", XS_Bio__Emboss_ajGraphxyDataNewI, file);
        newXS("Bio::Emboss::ajGraphxyDataSetSubtitle", XS_Bio__Emboss_ajGraphxyDataSetSubtitle, file);
        newXS("Bio::Emboss::ajGraphxyDataSetSubtitleC", XS_Bio__Emboss_ajGraphxyDataSetSubtitleC, file);
        newXS("Bio::Emboss::ajGraphxyDataSetTitle", XS_Bio__Emboss_ajGraphxyDataSetTitle, file);
        newXS("Bio::Emboss::ajGraphxyDataSetTitleC", XS_Bio__Emboss_ajGraphxyDataSetTitleC, file);
        newXS("Bio::Emboss::ajGraphxyDataSetXtitle", XS_Bio__Emboss_ajGraphxyDataSetXtitle, file);
        newXS("Bio::Emboss::ajGraphxyDataSetXtitleC", XS_Bio__Emboss_ajGraphxyDataSetXtitleC, file);
        newXS("Bio::Emboss::ajGraphxyDataSetYtitle", XS_Bio__Emboss_ajGraphxyDataSetYtitle, file);
        newXS("Bio::Emboss::ajGraphxyDataSetYtitleC", XS_Bio__Emboss_ajGraphxyDataSetYtitleC, file);
        newXS("Bio::Emboss::ajGraphxyDel", XS_Bio__Emboss_ajGraphxyDel, file);
        newXS("Bio::Emboss::ajGraphxyDisplay", XS_Bio__Emboss_ajGraphxyDisplay, file);
        newXS("Bio::Emboss::ajGraphxyInitGraphCalcPtr", XS_Bio__Emboss_ajGraphxyInitGraphCalcPtr, file);
        newXS("Bio::Emboss::ajGraphxyNewI", XS_Bio__Emboss_ajGraphxyNewI, file);
        newXS("Bio::Emboss::ajGraphxyCheckMaxMin", XS_Bio__Emboss_ajGraphxyCheckMaxMin, file);
        newXS("Bio::Emboss::ajGraphxySet", XS_Bio__Emboss_ajGraphxySet, file);
        newXS("Bio::Emboss::ajGraphxySetCirclePoints", XS_Bio__Emboss_ajGraphxySetCirclePoints, file);
        newXS("Bio::Emboss::ajGraphxySetColour", XS_Bio__Emboss_ajGraphxySetColour, file);
        newXS("Bio::Emboss::ajGraphxySetFlag", XS_Bio__Emboss_ajGraphxySetFlag, file);
        newXS("Bio::Emboss::ajGraphxySetGaps", XS_Bio__Emboss_ajGraphxySetGaps, file);
        newXS("Bio::Emboss::ajGraphxySetJoinPoints", XS_Bio__Emboss_ajGraphxySetJoinPoints, file);
        newXS("Bio::Emboss::ajGraphxySetLineType", XS_Bio__Emboss_ajGraphxySetLineType, file);
        newXS("Bio::Emboss::ajGraphxySetMaxMin", XS_Bio__Emboss_ajGraphxySetMaxMin, file);
        newXS("Bio::Emboss::ajGraphxySetOut", XS_Bio__Emboss_ajGraphxySetOut, file);
        newXS("Bio::Emboss::ajGraphxySetOutC", XS_Bio__Emboss_ajGraphxySetOutC, file);
        newXS("Bio::Emboss::ajGraphxySetOverLap", XS_Bio__Emboss_ajGraphxySetOverLap, file);
        newXS("Bio::Emboss::ajGraphxySetSubtitleDo", XS_Bio__Emboss_ajGraphxySetSubtitleDo, file);
        newXS("Bio::Emboss::ajGraphxySetTitleDo", XS_Bio__Emboss_ajGraphxySetTitleDo, file);
        newXS("Bio::Emboss::ajGraphxySetXBottom", XS_Bio__Emboss_ajGraphxySetXBottom, file);
        newXS("Bio::Emboss::ajGraphxySetXLabelTop", XS_Bio__Emboss_ajGraphxySetXLabelTop, file);
        newXS("Bio::Emboss::ajGraphxySetXTick", XS_Bio__Emboss_ajGraphxySetXTick, file);
        newXS("Bio::Emboss::ajGraphxySetXTop", XS_Bio__Emboss_ajGraphxySetXTop, file);
        newXS("Bio::Emboss::ajGraphxySetXEnd", XS_Bio__Emboss_ajGraphxySetXEnd, file);
        newXS("Bio::Emboss::ajGraphxySetXGrid", XS_Bio__Emboss_ajGraphxySetXGrid, file);
        newXS("Bio::Emboss::ajGraphxySetXInvTicks", XS_Bio__Emboss_ajGraphxySetXInvTicks, file);
        newXS("Bio::Emboss::ajGraphxySetXLabel", XS_Bio__Emboss_ajGraphxySetXLabel, file);
        newXS("Bio::Emboss::ajGraphxySetXRangeII", XS_Bio__Emboss_ajGraphxySetXRangeII, file);
        newXS("Bio::Emboss::ajGraphxySetXStart", XS_Bio__Emboss_ajGraphxySetXStart, file);
        newXS("Bio::Emboss::ajGraphxySetYLabelLeft", XS_Bio__Emboss_ajGraphxySetYLabelLeft, file);
        newXS("Bio::Emboss::ajGraphxySetYLeft", XS_Bio__Emboss_ajGraphxySetYLeft, file);
        newXS("Bio::Emboss::ajGraphxySetYRight", XS_Bio__Emboss_ajGraphxySetYRight, file);
        newXS("Bio::Emboss::ajGraphxySetYTick", XS_Bio__Emboss_ajGraphxySetYTick, file);
        newXS("Bio::Emboss::ajGraphxySetYEnd", XS_Bio__Emboss_ajGraphxySetYEnd, file);
        newXS("Bio::Emboss::ajGraphxySetYGrid", XS_Bio__Emboss_ajGraphxySetYGrid, file);
        newXS("Bio::Emboss::ajGraphxySetYInvTicks", XS_Bio__Emboss_ajGraphxySetYInvTicks, file);
        newXS("Bio::Emboss::ajGraphxySetYLabel", XS_Bio__Emboss_ajGraphxySetYLabel, file);
        newXS("Bio::Emboss::ajGraphxySetYRangeII", XS_Bio__Emboss_ajGraphxySetYRangeII, file);
        newXS("Bio::Emboss::ajGraphxySetYStart", XS_Bio__Emboss_ajGraphxySetYStart, file);
        newXS("Bio::Emboss::ajGraphxySubtitle", XS_Bio__Emboss_ajGraphxySubtitle, file);
        newXS("Bio::Emboss::ajGraphxySubtitleC", XS_Bio__Emboss_ajGraphxySubtitleC, file);
        newXS("Bio::Emboss::ajGraphxyTitle", XS_Bio__Emboss_ajGraphxyTitle, file);
        newXS("Bio::Emboss::ajGraphxyTitleC", XS_Bio__Emboss_ajGraphxyTitleC, file);
        newXS("Bio::Emboss::ajGraphxyXtitle", XS_Bio__Emboss_ajGraphxyXtitle, file);
        newXS("Bio::Emboss::ajGraphxyXtitleC", XS_Bio__Emboss_ajGraphxyXtitleC, file);
        newXS("Bio::Emboss::ajGraphxyYtitle", XS_Bio__Emboss_ajGraphxyYtitle, file);
        newXS("Bio::Emboss::ajGraphxyYtitleC", XS_Bio__Emboss_ajGraphxyYtitleC, file);
        newXS("Bio::Emboss::ajGraphPartCircle", XS_Bio__Emboss_ajGraphPartCircle, file);
        newXS("Bio::Emboss::ajGraphDrawTextOnCurve", XS_Bio__Emboss_ajGraphDrawTextOnCurve, file);
        newXS("Bio::Emboss::ajGraphRectangleOnCurve", XS_Bio__Emboss_ajGraphRectangleOnCurve, file);
        newXS("Bio::Emboss::ajGraphTextLength", XS_Bio__Emboss_ajGraphTextLength, file);
        newXS("Bio::Emboss::ajGraphTextHeight", XS_Bio__Emboss_ajGraphTextHeight, file);
        newXS("Bio::Emboss::ajGraphDistPts", XS_Bio__Emboss_ajGraphDistPts, file);
        newXS("Bio::Emboss::ajGraphFitTextOnLine", XS_Bio__Emboss_ajGraphFitTextOnLine, file);
        newXS("Bio::Emboss::ajGraphSetDefCharSize", XS_Bio__Emboss_ajGraphSetDefCharSize, file);
        newXS("Bio::Emboss::ajGraphFillRectangleOnCurve", XS_Bio__Emboss_ajGraphFillRectangleOnCurve, file);
        newXS("Bio::Emboss::ajHistClose", XS_Bio__Emboss_ajHistClose, file);
        newXS("Bio::Emboss::ajHistCopyData", XS_Bio__Emboss_ajHistCopyData, file);
        newXS("Bio::Emboss::ajHistDelete", XS_Bio__Emboss_ajHistDelete, file);
        newXS("Bio::Emboss::ajHistDisplay", XS_Bio__Emboss_ajHistDisplay, file);
        newXS("Bio::Emboss::ajHistNew", XS_Bio__Emboss_ajHistNew, file);
        newXS("Bio::Emboss::ajHistNewG", XS_Bio__Emboss_ajHistNewG, file);
        newXS("Bio::Emboss::ajHistSetBlackandWhite", XS_Bio__Emboss_ajHistSetBlackandWhite, file);
        newXS("Bio::Emboss::ajHistSetColour", XS_Bio__Emboss_ajHistSetColour, file);
        newXS("Bio::Emboss::ajHistSetMultiTitle", XS_Bio__Emboss_ajHistSetMultiTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiTitleC", XS_Bio__Emboss_ajHistSetMultiTitleC, file);
        newXS("Bio::Emboss::ajHistSetMultiXTitle", XS_Bio__Emboss_ajHistSetMultiXTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiXTitleC", XS_Bio__Emboss_ajHistSetMultiXTitleC, file);
        newXS("Bio::Emboss::ajHistSetMultiYTitle", XS_Bio__Emboss_ajHistSetMultiYTitle, file);
        newXS("Bio::Emboss::ajHistSetMultiYTitleC", XS_Bio__Emboss_ajHistSetMultiYTitleC, file);
        newXS("Bio::Emboss::ajHistSetPattern", XS_Bio__Emboss_ajHistSetPattern, file);
        newXS("Bio::Emboss::ajHistSetPtrToData", XS_Bio__Emboss_ajHistSetPtrToData, file);
        newXS("Bio::Emboss::ajHistSetTitleC", XS_Bio__Emboss_ajHistSetTitleC, file);
        newXS("Bio::Emboss::ajHistSetXAxisC", XS_Bio__Emboss_ajHistSetXAxisC, file);
        newXS("Bio::Emboss::ajHistSetYAxisLeftC", XS_Bio__Emboss_ajHistSetYAxisLeftC, file);
        newXS("Bio::Emboss::ajHistSetYAxisRightC", XS_Bio__Emboss_ajHistSetYAxisRightC, file);
        newXS("Bio::Emboss::ajListAppend", XS_Bio__Emboss_ajListAppend, file);
        newXS("Bio::Emboss::ajListCopy", XS_Bio__Emboss_ajListCopy, file);
        newXS("Bio::Emboss::ajListDel", XS_Bio__Emboss_ajListDel, file);
        newXS("Bio::Emboss::ajListFree", XS_Bio__Emboss_ajListFree, file);
        newXS("Bio::Emboss::ajListInsert", XS_Bio__Emboss_ajListInsert, file);
        newXS("Bio::Emboss::ajListIter", XS_Bio__Emboss_ajListIter, file);
        newXS("Bio::Emboss::ajListIterBack", XS_Bio__Emboss_ajListIterBack, file);
        newXS("Bio::Emboss::ajListIterBackDone", XS_Bio__Emboss_ajListIterBackDone, file);
        newXS("Bio::Emboss::ajListIterBackMore", XS_Bio__Emboss_ajListIterBackMore, file);
        newXS("Bio::Emboss::ajListIterBackNext", XS_Bio__Emboss_ajListIterBackNext, file);
        newXS("Bio::Emboss::ajListIterFree", XS_Bio__Emboss_ajListIterFree, file);
        newXS("Bio::Emboss::ajListIterNext", XS_Bio__Emboss_ajListIterNext, file);
        newXS("Bio::Emboss::ajListIterMore", XS_Bio__Emboss_ajListIterMore, file);
        newXS("Bio::Emboss::ajListIterDone", XS_Bio__Emboss_ajListIterDone, file);
        newXS("Bio::Emboss::ajListIterTrace", XS_Bio__Emboss_ajListIterTrace, file);
        newXS("Bio::Emboss::ajListLength", XS_Bio__Emboss_ajListLength, file);
        newXS("Bio::Emboss::ajListNew", XS_Bio__Emboss_ajListNew, file);
        newXS("Bio::Emboss::ajListPush", XS_Bio__Emboss_ajListPush, file);
        newXS("Bio::Emboss::ajListPushApp", XS_Bio__Emboss_ajListPushApp, file);
        newXS("Bio::Emboss::ajListReverse", XS_Bio__Emboss_ajListReverse, file);
        newXS("Bio::Emboss::ajListstrCopy", XS_Bio__Emboss_ajListstrCopy, file);
        newXS("Bio::Emboss::ajListstrDel", XS_Bio__Emboss_ajListstrDel, file);
        newXS("Bio::Emboss::ajListstrFree", XS_Bio__Emboss_ajListstrFree, file);
        newXS("Bio::Emboss::ajListstrIterTrace", XS_Bio__Emboss_ajListstrIterTrace, file);
        newXS("Bio::Emboss::ajListstrLength", XS_Bio__Emboss_ajListstrLength, file);
        newXS("Bio::Emboss::ajListstrNew", XS_Bio__Emboss_ajListstrNew, file);
        newXS("Bio::Emboss::ajListstrPop", XS_Bio__Emboss_ajListstrPop, file);
        newXS("Bio::Emboss::ajListstrPopEnd", XS_Bio__Emboss_ajListstrPopEnd, file);
        newXS("Bio::Emboss::ajListstrPush", XS_Bio__Emboss_ajListstrPush, file);
        newXS("Bio::Emboss::ajListstrPushApp", XS_Bio__Emboss_ajListstrPushApp, file);
        newXS("Bio::Emboss::ajListstrReverse", XS_Bio__Emboss_ajListstrReverse, file);
        newXS("Bio::Emboss::ajListstrToArray", XS_Bio__Emboss_ajListstrToArray, file);
        newXS("Bio::Emboss::ajListstrTrace", XS_Bio__Emboss_ajListstrTrace, file);
        newXS("Bio::Emboss::ajListTrace", XS_Bio__Emboss_ajListTrace, file);
        newXS("Bio::Emboss::ajListPushList", XS_Bio__Emboss_ajListPushList, file);
        newXS("Bio::Emboss::ajListstrPushList", XS_Bio__Emboss_ajListstrPushList, file);
        newXS("Bio::Emboss::ajListRemove", XS_Bio__Emboss_ajListRemove, file);
        newXS("Bio::Emboss::ajListstrClone", XS_Bio__Emboss_ajListstrClone, file);
        newXS("Bio::Emboss::ajListstrInsert", XS_Bio__Emboss_ajListstrInsert, file);
        newXS("Bio::Emboss::ajListstrRemove", XS_Bio__Emboss_ajListstrRemove, file);
        newXS("Bio::Emboss::ajListSort", XS_Bio__Emboss_ajListSort, file);
        newXS("Bio::Emboss::ajDegToRad", XS_Bio__Emboss_ajDegToRad, file);
        newXS("Bio::Emboss::ajGaussProb", XS_Bio__Emboss_ajGaussProb, file);
        newXS("Bio::Emboss::ajGeoMean", XS_Bio__Emboss_ajGeoMean, file);
        newXS("Bio::Emboss::ajPolToRec", XS_Bio__Emboss_ajPolToRec, file);
        newXS("Bio::Emboss::ajPosMod", XS_Bio__Emboss_ajPosMod, file);
        newXS("Bio::Emboss::ajRadToDeg", XS_Bio__Emboss_ajRadToDeg, file);
        newXS("Bio::Emboss::ajRandomNumber", XS_Bio__Emboss_ajRandomNumber, file);
        newXS("Bio::Emboss::ajRandomNumberD", XS_Bio__Emboss_ajRandomNumberD, file);
        newXS("Bio::Emboss::ajRandomSeed", XS_Bio__Emboss_ajRandomSeed, file);
        newXS("Bio::Emboss::ajRecToPol", XS_Bio__Emboss_ajRecToPol, file);
        newXS("Bio::Emboss::ajRound", XS_Bio__Emboss_ajRound, file);
        newXS("Bio::Emboss::ajRoundF", XS_Bio__Emboss_ajRoundF, file);
        newXS("Bio::Emboss::ajMemAlloc", XS_Bio__Emboss_ajMemAlloc, file);
        newXS("Bio::Emboss::ajMemCalloc", XS_Bio__Emboss_ajMemCalloc, file);
        newXS("Bio::Emboss::ajMemCalloc0", XS_Bio__Emboss_ajMemCalloc0, file);
        newXS("Bio::Emboss::ajMemFree", XS_Bio__Emboss_ajMemFree, file);
        newXS("Bio::Emboss::ajMemResize", XS_Bio__Emboss_ajMemResize, file);
        newXS("Bio::Emboss::ajMemStat", XS_Bio__Emboss_ajMemStat, file);
        newXS("Bio::Emboss::ajMemExit", XS_Bio__Emboss_ajMemExit, file);
        newXS("Bio::Emboss::ajNamDatabase", XS_Bio__Emboss_ajNamDatabase, file);
        newXS("Bio::Emboss::ajNamDbDetails", XS_Bio__Emboss_ajNamDbDetails, file);
        newXS("Bio::Emboss::ajNamDbGetDbalias", XS_Bio__Emboss_ajNamDbGetDbalias, file);
        newXS("Bio::Emboss::ajNamDbGetUrl", XS_Bio__Emboss_ajNamDbGetUrl, file);
        newXS("Bio::Emboss::ajNamDbData", XS_Bio__Emboss_ajNamDbData, file);
        newXS("Bio::Emboss::ajNamDbQuery", XS_Bio__Emboss_ajNamDbQuery, file);
        newXS("Bio::Emboss::ajNamDbTest", XS_Bio__Emboss_ajNamDbTest, file);
        newXS("Bio::Emboss::ajNamDebugOrigin", XS_Bio__Emboss_ajNamDebugOrigin, file);
        newXS("Bio::Emboss::ajNamDebugDatabases", XS_Bio__Emboss_ajNamDebugDatabases, file);
        newXS("Bio::Emboss::ajNamExit", XS_Bio__Emboss_ajNamExit, file);
        newXS("Bio::Emboss::ajNamGetenv", XS_Bio__Emboss_ajNamGetenv, file);
        newXS("Bio::Emboss::ajNamGetValue", XS_Bio__Emboss_ajNamGetValue, file);
        newXS("Bio::Emboss::ajNamGetValueC", XS_Bio__Emboss_ajNamGetValueC, file);
        newXS("Bio::Emboss::ajNamInit", XS_Bio__Emboss_ajNamInit, file);
        newXS("Bio::Emboss::ajNamListDatabases", XS_Bio__Emboss_ajNamListDatabases, file);
        newXS("Bio::Emboss::ajNamListListDatabases", XS_Bio__Emboss_ajNamListListDatabases, file);
        newXS("Bio::Emboss::ajNamListOrigin", XS_Bio__Emboss_ajNamListOrigin, file);
        newXS("Bio::Emboss::ajNamPrintDbAttr", XS_Bio__Emboss_ajNamPrintDbAttr, file);
        newXS("Bio::Emboss::ajNamResolve", XS_Bio__Emboss_ajNamResolve, file);
        newXS("Bio::Emboss::ajNamRoot", XS_Bio__Emboss_ajNamRoot, file);
        newXS("Bio::Emboss::ajNamRootBase", XS_Bio__Emboss_ajNamRootBase, file);
        newXS("Bio::Emboss::ajNamRootInstall", XS_Bio__Emboss_ajNamRootInstall, file);
        newXS("Bio::Emboss::ajNamRootPack", XS_Bio__Emboss_ajNamRootPack, file);
        newXS("Bio::Emboss::ajNamRootVersion", XS_Bio__Emboss_ajNamRootVersion, file);
        newXS("Bio::Emboss::ajRangeNewI", XS_Bio__Emboss_ajRangeNewI, file);
        newXS("Bio::Emboss::ajRangeDefault", XS_Bio__Emboss_ajRangeDefault, file);
        newXS("Bio::Emboss::ajRangeDel", XS_Bio__Emboss_ajRangeDel, file);
        newXS("Bio::Emboss::ajRangeGet", XS_Bio__Emboss_ajRangeGet, file);
        newXS("Bio::Emboss::ajRangeFile", XS_Bio__Emboss_ajRangeFile, file);
        newXS("Bio::Emboss::ajRangeNumber", XS_Bio__Emboss_ajRangeNumber, file);
        newXS("Bio::Emboss::ajRangeText", XS_Bio__Emboss_ajRangeText, file);
        newXS("Bio::Emboss::ajRangeValues", XS_Bio__Emboss_ajRangeValues, file);
        newXS("Bio::Emboss::ajRangeChange", XS_Bio__Emboss_ajRangeChange, file);
        newXS("Bio::Emboss::ajRangeBegin", XS_Bio__Emboss_ajRangeBegin, file);
        newXS("Bio::Emboss::ajRangeStrExtractList", XS_Bio__Emboss_ajRangeStrExtractList, file);
        newXS("Bio::Emboss::ajRangeStrExtract", XS_Bio__Emboss_ajRangeStrExtract, file);
        newXS("Bio::Emboss::ajRangeStrStuff", XS_Bio__Emboss_ajRangeStrStuff, file);
        newXS("Bio::Emboss::ajRangeStrMask", XS_Bio__Emboss_ajRangeStrMask, file);
        newXS("Bio::Emboss::ajRangeOverlapSingle", XS_Bio__Emboss_ajRangeOverlapSingle, file);
        newXS("Bio::Emboss::ajRangeOverlaps", XS_Bio__Emboss_ajRangeOverlaps, file);
        newXS("Bio::Emboss::ajRangeOrdered", XS_Bio__Emboss_ajRangeOrdered, file);
        newXS("Bio::Emboss::ajReportClose", XS_Bio__Emboss_ajReportClose, file);
        newXS("Bio::Emboss::ajReportDel", XS_Bio__Emboss_ajReportDel, file);
        newXS("Bio::Emboss::ajReportOpen", XS_Bio__Emboss_ajReportOpen, file);
        newXS("Bio::Emboss::ajReportFileAdd", XS_Bio__Emboss_ajReportFileAdd, file);
        newXS("Bio::Emboss::ajReportFindFormat", XS_Bio__Emboss_ajReportFindFormat, file);
        newXS("Bio::Emboss::ajReportFormatDefault", XS_Bio__Emboss_ajReportFormatDefault, file);
        newXS("Bio::Emboss::ajReportNew", XS_Bio__Emboss_ajReportNew, file);
        newXS("Bio::Emboss::ajReportPrintFormat", XS_Bio__Emboss_ajReportPrintFormat, file);
        newXS("Bio::Emboss::ajReportSeqName", XS_Bio__Emboss_ajReportSeqName, file);
        newXS("Bio::Emboss::ajReportSetHeader", XS_Bio__Emboss_ajReportSetHeader, file);
        newXS("Bio::Emboss::ajReportSetHeaderC", XS_Bio__Emboss_ajReportSetHeaderC, file);
        newXS("Bio::Emboss::ajReportSetTags", XS_Bio__Emboss_ajReportSetTags, file);
        newXS("Bio::Emboss::ajReportSetTail", XS_Bio__Emboss_ajReportSetTail, file);
        newXS("Bio::Emboss::ajReportSetTailC", XS_Bio__Emboss_ajReportSetTailC, file);
        newXS("Bio::Emboss::ajReportSetType", XS_Bio__Emboss_ajReportSetType, file);
        newXS("Bio::Emboss::ajReportWriteTail", XS_Bio__Emboss_ajReportWriteTail, file);
        newXS("Bio::Emboss::ajReportValid", XS_Bio__Emboss_ajReportValid, file);
        newXS("Bio::Emboss::ajReportWrite", XS_Bio__Emboss_ajReportWrite, file);
        newXS("Bio::Emboss::ajReportWriteHeader", XS_Bio__Emboss_ajReportWriteHeader, file);
        newXS("Bio::Emboss::ajIsAccession", XS_Bio__Emboss_ajIsAccession, file);
        newXS("Bio::Emboss::ajIsSeqversion", XS_Bio__Emboss_ajIsSeqversion, file);
        newXS("Bio::Emboss::ajSelexNew", XS_Bio__Emboss_ajSelexNew, file);
        newXS("Bio::Emboss::ajSelexDel", XS_Bio__Emboss_ajSelexDel, file);
        newXS("Bio::Emboss::ajSelexdataNew", XS_Bio__Emboss_ajSelexdataNew, file);
        newXS("Bio::Emboss::ajSelexdataDel", XS_Bio__Emboss_ajSelexdataDel, file);
        newXS("Bio::Emboss::ajSelexSQDel", XS_Bio__Emboss_ajSelexSQDel, file);
        newXS("Bio::Emboss::ajSelexSQNew", XS_Bio__Emboss_ajSelexSQNew, file);
        newXS("Bio::Emboss::ajStockholmNew", XS_Bio__Emboss_ajStockholmNew, file);
        newXS("Bio::Emboss::ajStockholmDel", XS_Bio__Emboss_ajStockholmDel, file);
        newXS("Bio::Emboss::ajStockholmdataDel", XS_Bio__Emboss_ajStockholmdataDel, file);
        newXS("Bio::Emboss::ajStockholmdataNew", XS_Bio__Emboss_ajStockholmdataNew, file);
        newXS("Bio::Emboss::ajSeqallBegin", XS_Bio__Emboss_ajSeqallBegin, file);
        newXS("Bio::Emboss::ajSeqallDel", XS_Bio__Emboss_ajSeqallDel, file);
        newXS("Bio::Emboss::ajSeqallEnd", XS_Bio__Emboss_ajSeqallEnd, file);
        newXS("Bio::Emboss::ajSeqallGetName", XS_Bio__Emboss_ajSeqallGetName, file);
        newXS("Bio::Emboss::ajSeqallGetNameSeq", XS_Bio__Emboss_ajSeqallGetNameSeq, file);
        newXS("Bio::Emboss::ajSeqallGetRange", XS_Bio__Emboss_ajSeqallGetRange, file);
        newXS("Bio::Emboss::ajSeqallGetUsa", XS_Bio__Emboss_ajSeqallGetUsa, file);
        newXS("Bio::Emboss::ajSeqallLen", XS_Bio__Emboss_ajSeqallLen, file);
        newXS("Bio::Emboss::ajSeqallNew", XS_Bio__Emboss_ajSeqallNew, file);
        newXS("Bio::Emboss::ajSeqallNext", XS_Bio__Emboss_ajSeqallNext, file);
        newXS("Bio::Emboss::ajSeqallReverse", XS_Bio__Emboss_ajSeqallReverse, file);
        newXS("Bio::Emboss::ajSeqallSetRange", XS_Bio__Emboss_ajSeqallSetRange, file);
        newXS("Bio::Emboss::ajSeqallToLower", XS_Bio__Emboss_ajSeqallToLower, file);
        newXS("Bio::Emboss::ajSeqallToUpper", XS_Bio__Emboss_ajSeqallToUpper, file);
        newXS("Bio::Emboss::ajSeqAssAcc", XS_Bio__Emboss_ajSeqAssAcc, file);
        newXS("Bio::Emboss::ajSeqAssAccC", XS_Bio__Emboss_ajSeqAssAccC, file);
        newXS("Bio::Emboss::ajSeqAssDesc", XS_Bio__Emboss_ajSeqAssDesc, file);
        newXS("Bio::Emboss::ajSeqAssDescC", XS_Bio__Emboss_ajSeqAssDescC, file);
        newXS("Bio::Emboss::ajSeqAssEntry", XS_Bio__Emboss_ajSeqAssEntry, file);
        newXS("Bio::Emboss::ajSeqAssEntryC", XS_Bio__Emboss_ajSeqAssEntryC, file);
        newXS("Bio::Emboss::ajSeqAssFile", XS_Bio__Emboss_ajSeqAssFile, file);
        newXS("Bio::Emboss::ajSeqAssFull", XS_Bio__Emboss_ajSeqAssFull, file);
        newXS("Bio::Emboss::ajSeqAssFullC", XS_Bio__Emboss_ajSeqAssFullC, file);
        newXS("Bio::Emboss::ajSeqAssGi", XS_Bio__Emboss_ajSeqAssGi, file);
        newXS("Bio::Emboss::ajSeqAssGiC", XS_Bio__Emboss_ajSeqAssGiC, file);
        newXS("Bio::Emboss::ajSeqAssName", XS_Bio__Emboss_ajSeqAssName, file);
        newXS("Bio::Emboss::ajSeqAssNameC", XS_Bio__Emboss_ajSeqAssNameC, file);
        newXS("Bio::Emboss::ajSeqAssSeq", XS_Bio__Emboss_ajSeqAssSeq, file);
        newXS("Bio::Emboss::ajSeqAssSeqC", XS_Bio__Emboss_ajSeqAssSeqC, file);
        newXS("Bio::Emboss::ajSeqAssSeqCI", XS_Bio__Emboss_ajSeqAssSeqCI, file);
        newXS("Bio::Emboss::ajSeqAssSv", XS_Bio__Emboss_ajSeqAssSv, file);
        newXS("Bio::Emboss::ajSeqAssSvC", XS_Bio__Emboss_ajSeqAssSvC, file);
        newXS("Bio::Emboss::ajSeqAssUfo", XS_Bio__Emboss_ajSeqAssUfo, file);
        newXS("Bio::Emboss::ajSeqAssUfoC", XS_Bio__Emboss_ajSeqAssUfoC, file);
        newXS("Bio::Emboss::ajSeqAssUsa", XS_Bio__Emboss_ajSeqAssUsa, file);
        newXS("Bio::Emboss::ajSeqAssUsaC", XS_Bio__Emboss_ajSeqAssUsaC, file);
        newXS("Bio::Emboss::ajSeqBaseComp", XS_Bio__Emboss_ajSeqBaseComp, file);
        newXS("Bio::Emboss::ajSeqBegin", XS_Bio__Emboss_ajSeqBegin, file);
        newXS("Bio::Emboss::ajSeqChar", XS_Bio__Emboss_ajSeqChar, file);
        newXS("Bio::Emboss::ajSeqCharCopy", XS_Bio__Emboss_ajSeqCharCopy, file);
        newXS("Bio::Emboss::ajSeqCharCopyL", XS_Bio__Emboss_ajSeqCharCopyL, file);
        newXS("Bio::Emboss::ajSeqCheckGcg", XS_Bio__Emboss_ajSeqCheckGcg, file);
        newXS("Bio::Emboss::ajSeqClear", XS_Bio__Emboss_ajSeqClear, file);
        newXS("Bio::Emboss::ajSeqCompOnly", XS_Bio__Emboss_ajSeqCompOnly, file);
        newXS("Bio::Emboss::ajSeqCompOnlyStr", XS_Bio__Emboss_ajSeqCompOnlyStr, file);
        newXS("Bio::Emboss::ajSeqCopyFeat", XS_Bio__Emboss_ajSeqCopyFeat, file);
        newXS("Bio::Emboss::ajSeqCount", XS_Bio__Emboss_ajSeqCount, file);
        newXS("Bio::Emboss::ajSeqCrc", XS_Bio__Emboss_ajSeqCrc, file);
        newXS("Bio::Emboss::ajSeqCvtDel", XS_Bio__Emboss_ajSeqCvtDel, file);
        newXS("Bio::Emboss::ajSeqCvtK", XS_Bio__Emboss_ajSeqCvtK, file);
        newXS("Bio::Emboss::ajSeqCvtLen", XS_Bio__Emboss_ajSeqCvtLen, file);
        newXS("Bio::Emboss::ajSeqCvtNew", XS_Bio__Emboss_ajSeqCvtNew, file);
        newXS("Bio::Emboss::ajSeqCvtNewText", XS_Bio__Emboss_ajSeqCvtNewText, file);
        newXS("Bio::Emboss::ajSeqCvtNewZero", XS_Bio__Emboss_ajSeqCvtNewZero, file);
        newXS("Bio::Emboss::ajSeqCvtTrace", XS_Bio__Emboss_ajSeqCvtTrace, file);
        newXS("Bio::Emboss::ajSeqDel", XS_Bio__Emboss_ajSeqDel, file);
        newXS("Bio::Emboss::ajSeqEnd", XS_Bio__Emboss_ajSeqEnd, file);
        newXS("Bio::Emboss::ajSeqFill", XS_Bio__Emboss_ajSeqFill, file);
        newXS("Bio::Emboss::ajSeqGapCount", XS_Bio__Emboss_ajSeqGapCount, file);
        newXS("Bio::Emboss::ajSeqGapCountS", XS_Bio__Emboss_ajSeqGapCountS, file);
        newXS("Bio::Emboss::ajSeqGapStandard", XS_Bio__Emboss_ajSeqGapStandard, file);
        newXS("Bio::Emboss::ajSeqGetAcc", XS_Bio__Emboss_ajSeqGetAcc, file);
        newXS("Bio::Emboss::ajSeqGetDesc", XS_Bio__Emboss_ajSeqGetDesc, file);
        newXS("Bio::Emboss::ajSeqGetEntry", XS_Bio__Emboss_ajSeqGetEntry, file);
        newXS("Bio::Emboss::ajSeqGetFeat", XS_Bio__Emboss_ajSeqGetFeat, file);
        newXS("Bio::Emboss::ajSeqGetGi", XS_Bio__Emboss_ajSeqGetGi, file);
        newXS("Bio::Emboss::ajSeqGetName", XS_Bio__Emboss_ajSeqGetName, file);
        newXS("Bio::Emboss::ajSeqGetRange", XS_Bio__Emboss_ajSeqGetRange, file);
        newXS("Bio::Emboss::ajSeqGetReverse", XS_Bio__Emboss_ajSeqGetReverse, file);
        newXS("Bio::Emboss::ajSeqGetSv", XS_Bio__Emboss_ajSeqGetSv, file);
        newXS("Bio::Emboss::ajSeqGetUsa", XS_Bio__Emboss_ajSeqGetUsa, file);
        newXS("Bio::Emboss::ajSeqinTrace", XS_Bio__Emboss_ajSeqinTrace, file);
        newXS("Bio::Emboss::ajSeqIsNuc", XS_Bio__Emboss_ajSeqIsNuc, file);
        newXS("Bio::Emboss::ajSeqIsProt", XS_Bio__Emboss_ajSeqIsProt, file);
        newXS("Bio::Emboss::ajSeqLen", XS_Bio__Emboss_ajSeqLen, file);
        newXS("Bio::Emboss::ajSeqMakeUsa", XS_Bio__Emboss_ajSeqMakeUsa, file);
        newXS("Bio::Emboss::ajSeqMod", XS_Bio__Emboss_ajSeqMod, file);
        newXS("Bio::Emboss::ajSeqMW", XS_Bio__Emboss_ajSeqMW, file);
        newXS("Bio::Emboss::ajSeqName", XS_Bio__Emboss_ajSeqName, file);
        newXS("Bio::Emboss::ajSeqNew", XS_Bio__Emboss_ajSeqNew, file);
        newXS("Bio::Emboss::ajSeqNewL", XS_Bio__Emboss_ajSeqNewL, file);
        newXS("Bio::Emboss::ajSeqNewS", XS_Bio__Emboss_ajSeqNewS, file);
        newXS("Bio::Emboss::ajSeqNum", XS_Bio__Emboss_ajSeqNum, file);
        newXS("Bio::Emboss::ajSeqOffset", XS_Bio__Emboss_ajSeqOffset, file);
        newXS("Bio::Emboss::ajSeqOffend", XS_Bio__Emboss_ajSeqOffend, file);
        newXS("Bio::Emboss::ajSeqPos", XS_Bio__Emboss_ajSeqPos, file);
        newXS("Bio::Emboss::ajSeqPosI", XS_Bio__Emboss_ajSeqPosI, file);
        newXS("Bio::Emboss::ajSeqPosII", XS_Bio__Emboss_ajSeqPosII, file);
        newXS("Bio::Emboss::ajSeqQueryClear", XS_Bio__Emboss_ajSeqQueryClear, file);
        newXS("Bio::Emboss::ajSeqQueryDel", XS_Bio__Emboss_ajSeqQueryDel, file);
        newXS("Bio::Emboss::ajSeqQueryIs", XS_Bio__Emboss_ajSeqQueryIs, file);
        newXS("Bio::Emboss::ajSeqQueryNew", XS_Bio__Emboss_ajSeqQueryNew, file);
        newXS("Bio::Emboss::ajSeqQueryStarclear", XS_Bio__Emboss_ajSeqQueryStarclear, file);
        newXS("Bio::Emboss::ajSeqQueryTrace", XS_Bio__Emboss_ajSeqQueryTrace, file);
        newXS("Bio::Emboss::ajSeqQueryWild", XS_Bio__Emboss_ajSeqQueryWild, file);
        newXS("Bio::Emboss::ajSeqReplace", XS_Bio__Emboss_ajSeqReplace, file);
        newXS("Bio::Emboss::ajSeqReplaceC", XS_Bio__Emboss_ajSeqReplaceC, file);
        newXS("Bio::Emboss::ajSeqReverse", XS_Bio__Emboss_ajSeqReverse, file);
        newXS("Bio::Emboss::ajSeqReverseStr", XS_Bio__Emboss_ajSeqReverseStr, file);
        newXS("Bio::Emboss::ajSeqRevOnly", XS_Bio__Emboss_ajSeqRevOnly, file);
        newXS("Bio::Emboss::ajSeqsetBegin", XS_Bio__Emboss_ajSeqsetBegin, file);
        newXS("Bio::Emboss::ajSeqsetDel", XS_Bio__Emboss_ajSeqsetDel, file);
        newXS("Bio::Emboss::ajSeqsetEnd", XS_Bio__Emboss_ajSeqsetEnd, file);
        newXS("Bio::Emboss::ajSeqsetFill", XS_Bio__Emboss_ajSeqsetFill, file);
        newXS("Bio::Emboss::ajSeqsetGetFormat", XS_Bio__Emboss_ajSeqsetGetFormat, file);
        newXS("Bio::Emboss::ajSeqsetGetName", XS_Bio__Emboss_ajSeqsetGetName, file);
        newXS("Bio::Emboss::ajSeqsetGetRange", XS_Bio__Emboss_ajSeqsetGetRange, file);
        newXS("Bio::Emboss::ajSeqsetGetSeq", XS_Bio__Emboss_ajSeqsetGetSeq, file);
        newXS("Bio::Emboss::ajSeqsetGetUsa", XS_Bio__Emboss_ajSeqsetGetUsa, file);
        newXS("Bio::Emboss::ajSeqsetIsDna", XS_Bio__Emboss_ajSeqsetIsDna, file);
        newXS("Bio::Emboss::ajSeqsetIsNuc", XS_Bio__Emboss_ajSeqsetIsNuc, file);
        newXS("Bio::Emboss::ajSeqsetIsProt", XS_Bio__Emboss_ajSeqsetIsProt, file);
        newXS("Bio::Emboss::ajSeqsetIsRna", XS_Bio__Emboss_ajSeqsetIsRna, file);
        newXS("Bio::Emboss::ajSeqsetLen", XS_Bio__Emboss_ajSeqsetLen, file);
        newXS("Bio::Emboss::ajSeqsetName", XS_Bio__Emboss_ajSeqsetName, file);
        newXS("Bio::Emboss::ajSeqsetNew", XS_Bio__Emboss_ajSeqsetNew, file);
        newXS("Bio::Emboss::ajSeqSetRange", XS_Bio__Emboss_ajSeqSetRange, file);
        newXS("Bio::Emboss::ajSeqsetReverse", XS_Bio__Emboss_ajSeqsetReverse, file);
        newXS("Bio::Emboss::ajSeqsetSeq", XS_Bio__Emboss_ajSeqsetSeq, file);
        newXS("Bio::Emboss::ajSeqsetSetRange", XS_Bio__Emboss_ajSeqsetSetRange, file);
        newXS("Bio::Emboss::ajSeqsetSize", XS_Bio__Emboss_ajSeqsetSize, file);
        newXS("Bio::Emboss::ajSeqsetToLower", XS_Bio__Emboss_ajSeqsetToLower, file);
        newXS("Bio::Emboss::ajSeqsetTotweight", XS_Bio__Emboss_ajSeqsetTotweight, file);
        newXS("Bio::Emboss::ajSeqsetToUpper", XS_Bio__Emboss_ajSeqsetToUpper, file);
        newXS("Bio::Emboss::ajSeqsetWeight", XS_Bio__Emboss_ajSeqsetWeight, file);
        newXS("Bio::Emboss::ajSeqStr", XS_Bio__Emboss_ajSeqStr, file);
        newXS("Bio::Emboss::ajSeqStrCopy", XS_Bio__Emboss_ajSeqStrCopy, file);
        newXS("Bio::Emboss::ajSeqToLower", XS_Bio__Emboss_ajSeqToLower, file);
        newXS("Bio::Emboss::ajSeqToUpper", XS_Bio__Emboss_ajSeqToUpper, file);
        newXS("Bio::Emboss::ajSeqTrace", XS_Bio__Emboss_ajSeqTrace, file);
        newXS("Bio::Emboss::ajSeqFindOutFormat", XS_Bio__Emboss_ajSeqFindOutFormat, file);
        newXS("Bio::Emboss::ajSeqTrim", XS_Bio__Emboss_ajSeqTrim, file);
        newXS("Bio::Emboss::ajSeqABIGetBaseOffset", XS_Bio__Emboss_ajSeqABIGetBaseOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetBasePosition", XS_Bio__Emboss_ajSeqABIGetBasePosition, file);
        newXS("Bio::Emboss::ajSeqABIGetBasePosOffset", XS_Bio__Emboss_ajSeqABIGetBasePosOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetBaseSpace", XS_Bio__Emboss_ajSeqABIGetBaseSpace, file);
        newXS("Bio::Emboss::ajSeqABIGetData", XS_Bio__Emboss_ajSeqABIGetData, file);
        newXS("Bio::Emboss::ajSeqABIGetFWO", XS_Bio__Emboss_ajSeqABIGetFWO, file);
        newXS("Bio::Emboss::ajSeqABIGetNBase", XS_Bio__Emboss_ajSeqABIGetNBase, file);
        newXS("Bio::Emboss::ajSeqABIGetNData", XS_Bio__Emboss_ajSeqABIGetNData, file);
        newXS("Bio::Emboss::ajSeqABIGetPrimerOffset", XS_Bio__Emboss_ajSeqABIGetPrimerOffset, file);
        newXS("Bio::Emboss::ajSeqABIGetPrimerPosition", XS_Bio__Emboss_ajSeqABIGetPrimerPosition, file);
        newXS("Bio::Emboss::ajSeqABIGetSignal", XS_Bio__Emboss_ajSeqABIGetSignal, file);
        newXS("Bio::Emboss::ajSeqABIGetTraceOffset", XS_Bio__Emboss_ajSeqABIGetTraceOffset, file);
        newXS("Bio::Emboss::ajSeqABIMachineName", XS_Bio__Emboss_ajSeqABIMachineName, file);
        newXS("Bio::Emboss::ajSeqABIReadSeq", XS_Bio__Emboss_ajSeqABIReadSeq, file);
        newXS("Bio::Emboss::ajSeqABISampleName", XS_Bio__Emboss_ajSeqABISampleName, file);
        newXS("Bio::Emboss::ajSeqABITest", XS_Bio__Emboss_ajSeqABITest, file);
        newXS("Bio::Emboss::ajSeqAccessAsis", XS_Bio__Emboss_ajSeqAccessAsis, file);
        newXS("Bio::Emboss::ajSeqAccessFile", XS_Bio__Emboss_ajSeqAccessFile, file);
        newXS("Bio::Emboss::ajSeqAccessOffset", XS_Bio__Emboss_ajSeqAccessOffset, file);
        newXS("Bio::Emboss::ajSeqMethod", XS_Bio__Emboss_ajSeqMethod, file);
        newXS("Bio::Emboss::ajSeqPrintAccess", XS_Bio__Emboss_ajSeqPrintAccess, file);
        newXS("Bio::Emboss::ajSeqallFile", XS_Bio__Emboss_ajSeqallFile, file);
        newXS("Bio::Emboss::ajSeqAllRead", XS_Bio__Emboss_ajSeqAllRead, file);
        newXS("Bio::Emboss::ajSeqGetFromUsa", XS_Bio__Emboss_ajSeqGetFromUsa, file);
        newXS("Bio::Emboss::ajSeqinClear", XS_Bio__Emboss_ajSeqinClear, file);
        newXS("Bio::Emboss::ajSeqinDel", XS_Bio__Emboss_ajSeqinDel, file);
        newXS("Bio::Emboss::ajSeqinNew", XS_Bio__Emboss_ajSeqinNew, file);
        newXS("Bio::Emboss::ajSeqParseFasta", XS_Bio__Emboss_ajSeqParseFasta, file);
        newXS("Bio::Emboss::ajSeqParseNcbi", XS_Bio__Emboss_ajSeqParseNcbi, file);
        newXS("Bio::Emboss::ajSeqinSetNuc", XS_Bio__Emboss_ajSeqinSetNuc, file);
        newXS("Bio::Emboss::ajSeqinSetProt", XS_Bio__Emboss_ajSeqinSetProt, file);
        newXS("Bio::Emboss::ajSeqinSetRange", XS_Bio__Emboss_ajSeqinSetRange, file);
        newXS("Bio::Emboss::ajSeqinUsa", XS_Bio__Emboss_ajSeqinUsa, file);
        newXS("Bio::Emboss::ajSeqPrintInFormat", XS_Bio__Emboss_ajSeqPrintInFormat, file);
        newXS("Bio::Emboss::ajSeqRead", XS_Bio__Emboss_ajSeqRead, file);
        newXS("Bio::Emboss::ajSeqsetApp", XS_Bio__Emboss_ajSeqsetApp, file);
        newXS("Bio::Emboss::ajSeqsetRead", XS_Bio__Emboss_ajSeqsetRead, file);
        newXS("Bio::Emboss::ajSeqsetFromList", XS_Bio__Emboss_ajSeqsetFromList, file);
        newXS("Bio::Emboss::ajSeqsetFromPair", XS_Bio__Emboss_ajSeqsetFromPair, file);
        newXS("Bio::Emboss::ajSeqGap", XS_Bio__Emboss_ajSeqGap, file);
        newXS("Bio::Emboss::ajSeqGapLen", XS_Bio__Emboss_ajSeqGapLen, file);
        newXS("Bio::Emboss::ajSeqGapS", XS_Bio__Emboss_ajSeqGapS, file);
        newXS("Bio::Emboss::ajSeqPrintType", XS_Bio__Emboss_ajSeqPrintType, file);
        newXS("Bio::Emboss::ajSeqSetNuc", XS_Bio__Emboss_ajSeqSetNuc, file);
        newXS("Bio::Emboss::ajSeqSetProt", XS_Bio__Emboss_ajSeqSetProt, file);
        newXS("Bio::Emboss::ajSeqType", XS_Bio__Emboss_ajSeqType, file);
        newXS("Bio::Emboss::ajSeqAllWrite", XS_Bio__Emboss_ajSeqAllWrite, file);
        newXS("Bio::Emboss::ajSeqFileNewOut", XS_Bio__Emboss_ajSeqFileNewOut, file);
        newXS("Bio::Emboss::ajSeqoutCheckGcg", XS_Bio__Emboss_ajSeqoutCheckGcg, file);
        newXS("Bio::Emboss::ajSeqoutClear", XS_Bio__Emboss_ajSeqoutClear, file);
        newXS("Bio::Emboss::ajSeqoutDel", XS_Bio__Emboss_ajSeqoutDel, file);
        newXS("Bio::Emboss::ajSeqOutFormatDefault", XS_Bio__Emboss_ajSeqOutFormatDefault, file);
        newXS("Bio::Emboss::ajSeqOutFormatSingle", XS_Bio__Emboss_ajSeqOutFormatSingle, file);
        newXS("Bio::Emboss::ajSeqoutNew", XS_Bio__Emboss_ajSeqoutNew, file);
        newXS("Bio::Emboss::ajSeqoutNewF", XS_Bio__Emboss_ajSeqoutNewF, file);
        newXS("Bio::Emboss::ajSeqoutOpen", XS_Bio__Emboss_ajSeqoutOpen, file);
        newXS("Bio::Emboss::ajSeqOutSetFormat", XS_Bio__Emboss_ajSeqOutSetFormat, file);
        newXS("Bio::Emboss::ajSeqOutSetFormatC", XS_Bio__Emboss_ajSeqOutSetFormatC, file);
        newXS("Bio::Emboss::ajSeqoutTrace", XS_Bio__Emboss_ajSeqoutTrace, file);
        newXS("Bio::Emboss::ajSeqPrintOutFormat", XS_Bio__Emboss_ajSeqPrintOutFormat, file);
        newXS("Bio::Emboss::ajSeqoutUsa", XS_Bio__Emboss_ajSeqoutUsa, file);
        newXS("Bio::Emboss::ajSeqsetWrite", XS_Bio__Emboss_ajSeqsetWrite, file);
        newXS("Bio::Emboss::ajSeqWrite", XS_Bio__Emboss_ajSeqWrite, file);
        newXS("Bio::Emboss::ajSeqWriteClose", XS_Bio__Emboss_ajSeqWriteClose, file);
        newXS("Bio::Emboss::ajSeqWriteXyz", XS_Bio__Emboss_ajSeqWriteXyz, file);
#ifdef HAVE_EMBOSS_2_6_0
        newXS("Bio::Emboss::ajSssWriteXyz", XS_Bio__Emboss_ajSssWriteXyz, file);
#endif
        newXS("Bio::Emboss::ajCharFree", XS_Bio__Emboss_ajCharFree, file);
        newXS("Bio::Emboss::ajCharNewC", XS_Bio__Emboss_ajCharNewC, file);
        newXS("Bio::Emboss::ajCharNew", XS_Bio__Emboss_ajCharNew, file);
        newXS("Bio::Emboss::ajCharNewL", XS_Bio__Emboss_ajCharNewL, file);
        newXS("Bio::Emboss::ajCharNewLS", XS_Bio__Emboss_ajCharNewLS, file);
        newXS("Bio::Emboss::ajCharPos", XS_Bio__Emboss_ajCharPos, file);
        newXS("Bio::Emboss::ajCharToLower", XS_Bio__Emboss_ajCharToLower, file);
        newXS("Bio::Emboss::ajCharToUpper", XS_Bio__Emboss_ajCharToUpper, file);
        newXS("Bio::Emboss::ajStrApp", XS_Bio__Emboss_ajStrApp, file);
        newXS("Bio::Emboss::ajStrAppC", XS_Bio__Emboss_ajStrAppC, file);
        newXS("Bio::Emboss::ajStrAppK", XS_Bio__Emboss_ajStrAppK, file);
        newXS("Bio::Emboss::ajStrAppKI", XS_Bio__Emboss_ajStrAppKI, file);
        newXS("Bio::Emboss::ajStrAppSub", XS_Bio__Emboss_ajStrAppSub, file);
        newXS("Bio::Emboss::ajStrAss", XS_Bio__Emboss_ajStrAss, file);
        newXS("Bio::Emboss::ajStrAssC", XS_Bio__Emboss_ajStrAssC, file);
        newXS("Bio::Emboss::ajStrAssCI", XS_Bio__Emboss_ajStrAssCI, file);
        newXS("Bio::Emboss::ajStrAssCL", XS_Bio__Emboss_ajStrAssCL, file);
        newXS("Bio::Emboss::ajStrAssI", XS_Bio__Emboss_ajStrAssI, file);
        newXS("Bio::Emboss::ajStrAssL", XS_Bio__Emboss_ajStrAssL, file);
        newXS("Bio::Emboss::ajStrAssS", XS_Bio__Emboss_ajStrAssS, file);
        newXS("Bio::Emboss::ajStrAssSub", XS_Bio__Emboss_ajStrAssSub, file);
        newXS("Bio::Emboss::ajStrAssSubC", XS_Bio__Emboss_ajStrAssSubC, file);
        newXS("Bio::Emboss::ajStrBlock", XS_Bio__Emboss_ajStrBlock, file);
        newXS("Bio::Emboss::ajStrBool", XS_Bio__Emboss_ajStrBool, file);
        newXS("Bio::Emboss::ajStrChar", XS_Bio__Emboss_ajStrChar, file);
        newXS("Bio::Emboss::ajStrCheck", XS_Bio__Emboss_ajStrCheck, file);
        newXS("Bio::Emboss::ajStrChomp", XS_Bio__Emboss_ajStrChomp, file);
        newXS("Bio::Emboss::ajStrChompC", XS_Bio__Emboss_ajStrChompC, file);
        newXS("Bio::Emboss::ajStrChompEnd", XS_Bio__Emboss_ajStrChompEnd, file);
        newXS("Bio::Emboss::ajStrChop", XS_Bio__Emboss_ajStrChop, file);
        newXS("Bio::Emboss::ajStrClean", XS_Bio__Emboss_ajStrClean, file);
        newXS("Bio::Emboss::ajStrCleanWhite", XS_Bio__Emboss_ajStrCleanWhite, file);
        newXS("Bio::Emboss::ajStrClear", XS_Bio__Emboss_ajStrClear, file);
        newXS("Bio::Emboss::ajStrCmpC", XS_Bio__Emboss_ajStrCmpC, file);
        newXS("Bio::Emboss::ajStrCmpCase", XS_Bio__Emboss_ajStrCmpCase, file);
        newXS("Bio::Emboss::ajStrCmpCaseCC", XS_Bio__Emboss_ajStrCmpCaseCC, file);
        newXS("Bio::Emboss::ajStrCmp", XS_Bio__Emboss_ajStrCmp, file);
        newXS("Bio::Emboss::ajStrCmpO", XS_Bio__Emboss_ajStrCmpO, file);
        newXS("Bio::Emboss::ajStrCmpWild", XS_Bio__Emboss_ajStrCmpWild, file);
        newXS("Bio::Emboss::ajStrCmpWildC", XS_Bio__Emboss_ajStrCmpWildC, file);
        newXS("Bio::Emboss::ajStrCmpWildCC", XS_Bio__Emboss_ajStrCmpWildCC, file);
        newXS("Bio::Emboss::ajStrConvert", XS_Bio__Emboss_ajStrConvert, file);
        newXS("Bio::Emboss::ajStrConvertCC", XS_Bio__Emboss_ajStrConvertCC, file);
        newXS("Bio::Emboss::ajStrCopy", XS_Bio__Emboss_ajStrCopy, file);
        newXS("Bio::Emboss::ajStrCopyC", XS_Bio__Emboss_ajStrCopyC, file);
        newXS("Bio::Emboss::ajStrCountC", XS_Bio__Emboss_ajStrCountC, file);
        newXS("Bio::Emboss::ajStrCountK", XS_Bio__Emboss_ajStrCountK, file);
        newXS("Bio::Emboss::ajStrCut", XS_Bio__Emboss_ajStrCut, file);
        newXS("Bio::Emboss::ajStrDegap", XS_Bio__Emboss_ajStrDegap, file);
        newXS("Bio::Emboss::ajStrDel", XS_Bio__Emboss_ajStrDel, file);
        newXS("Bio::Emboss::ajStrDelim", XS_Bio__Emboss_ajStrDelim, file);
        newXS("Bio::Emboss::ajStrDelReuse", XS_Bio__Emboss_ajStrDelReuse, file);
        newXS("Bio::Emboss::ajStrDup", XS_Bio__Emboss_ajStrDup, file);
        newXS("Bio::Emboss::ajStrExit", XS_Bio__Emboss_ajStrExit, file);
        newXS("Bio::Emboss::ajStrFind", XS_Bio__Emboss_ajStrFind, file);
        newXS("Bio::Emboss::ajStrFindC", XS_Bio__Emboss_ajStrFindC, file);
        newXS("Bio::Emboss::ajStrFindCase", XS_Bio__Emboss_ajStrFindCase, file);
        newXS("Bio::Emboss::ajStrFindCaseC", XS_Bio__Emboss_ajStrFindCaseC, file);
        newXS("Bio::Emboss::ajStrFill", XS_Bio__Emboss_ajStrFill, file);
        newXS("Bio::Emboss::ajStrFix", XS_Bio__Emboss_ajStrFix, file);
        newXS("Bio::Emboss::ajStrFixI", XS_Bio__Emboss_ajStrFixI, file);
        newXS("Bio::Emboss::ajStrFixTestI", XS_Bio__Emboss_ajStrFixTestI, file);
        newXS("Bio::Emboss::ajStrFromBool", XS_Bio__Emboss_ajStrFromBool, file);
        newXS("Bio::Emboss::ajStrFromDouble", XS_Bio__Emboss_ajStrFromDouble, file);
        newXS("Bio::Emboss::ajStrFromDoubleE", XS_Bio__Emboss_ajStrFromDoubleE, file);
        newXS("Bio::Emboss::ajStrFromFloat", XS_Bio__Emboss_ajStrFromFloat, file);
        newXS("Bio::Emboss::ajStrFromInt", XS_Bio__Emboss_ajStrFromInt, file);
        newXS("Bio::Emboss::ajStrFromLong", XS_Bio__Emboss_ajStrFromLong, file);
        newXS("Bio::Emboss::ajStrInsert", XS_Bio__Emboss_ajStrInsert, file);
        newXS("Bio::Emboss::ajStrInsertC", XS_Bio__Emboss_ajStrInsertC, file);
        newXS("Bio::Emboss::ajStrIsAlnum", XS_Bio__Emboss_ajStrIsAlnum, file);
        newXS("Bio::Emboss::ajStrIsAlpha", XS_Bio__Emboss_ajStrIsAlpha, file);
        newXS("Bio::Emboss::ajStrIsBool", XS_Bio__Emboss_ajStrIsBool, file);
        newXS("Bio::Emboss::ajStrIsDouble", XS_Bio__Emboss_ajStrIsDouble, file);
        newXS("Bio::Emboss::ajStrIsFloat", XS_Bio__Emboss_ajStrIsFloat, file);
        newXS("Bio::Emboss::ajStrIsHex", XS_Bio__Emboss_ajStrIsHex, file);
        newXS("Bio::Emboss::ajStrIsInt", XS_Bio__Emboss_ajStrIsInt, file);
        newXS("Bio::Emboss::ajStrIsLong", XS_Bio__Emboss_ajStrIsLong, file);
        newXS("Bio::Emboss::ajStrIsSpace", XS_Bio__Emboss_ajStrIsSpace, file);
        newXS("Bio::Emboss::ajStrIsWild", XS_Bio__Emboss_ajStrIsWild, file);
        newXS("Bio::Emboss::ajStrIsWord", XS_Bio__Emboss_ajStrIsWord, file);
        newXS("Bio::Emboss::ajStrIter", XS_Bio__Emboss_ajStrIter, file);
        newXS("Bio::Emboss::ajStrIterBack", XS_Bio__Emboss_ajStrIterBack, file);
        newXS("Bio::Emboss::ajStrIterBackNext", XS_Bio__Emboss_ajStrIterBackNext, file);
        newXS("Bio::Emboss::ajStrIterFree", XS_Bio__Emboss_ajStrIterFree, file);
        newXS("Bio::Emboss::ajStrIterNext", XS_Bio__Emboss_ajStrIterNext, file);
        newXS("Bio::Emboss::ajStrJoin", XS_Bio__Emboss_ajStrJoin, file);
        newXS("Bio::Emboss::ajStrJoinC", XS_Bio__Emboss_ajStrJoinC, file);
        newXS("Bio::Emboss::ajStrLen", XS_Bio__Emboss_ajStrLen, file);
        newXS("Bio::Emboss::ajStrMask", XS_Bio__Emboss_ajStrMask, file);
        newXS("Bio::Emboss::ajStrMatch", XS_Bio__Emboss_ajStrMatch, file);
        newXS("Bio::Emboss::ajStrMatchC", XS_Bio__Emboss_ajStrMatchC, file);
        newXS("Bio::Emboss::ajStrMatchCase", XS_Bio__Emboss_ajStrMatchCase, file);
        newXS("Bio::Emboss::ajStrMatchCaseC", XS_Bio__Emboss_ajStrMatchCaseC, file);
        newXS("Bio::Emboss::ajStrMatchCaseCC", XS_Bio__Emboss_ajStrMatchCaseCC, file);
        newXS("Bio::Emboss::ajStrMatchCC", XS_Bio__Emboss_ajStrMatchCC, file);
        newXS("Bio::Emboss::ajStrMatchWild", XS_Bio__Emboss_ajStrMatchWild, file);
        newXS("Bio::Emboss::ajStrMatchWildC", XS_Bio__Emboss_ajStrMatchWildC, file);
        newXS("Bio::Emboss::ajStrMatchWildCC", XS_Bio__Emboss_ajStrMatchWildCC, file);
        newXS("Bio::Emboss::ajStrMatchWildCO", XS_Bio__Emboss_ajStrMatchWildCO, file);
        newXS("Bio::Emboss::ajStrMatchWord", XS_Bio__Emboss_ajStrMatchWord, file);
        newXS("Bio::Emboss::ajStrMatchWordC", XS_Bio__Emboss_ajStrMatchWordC, file);
        newXS("Bio::Emboss::ajStrMatchWordCC", XS_Bio__Emboss_ajStrMatchWordCC, file);
        newXS("Bio::Emboss::ajStrMod", XS_Bio__Emboss_ajStrMod, file);
        newXS("Bio::Emboss::ajStrModL", XS_Bio__Emboss_ajStrModL, file);
        newXS("Bio::Emboss::ajStrNCmpC", XS_Bio__Emboss_ajStrNCmpC, file);
        newXS("Bio::Emboss::ajStrNCmpCaseCC", XS_Bio__Emboss_ajStrNCmpCaseCC, file);
        newXS("Bio::Emboss::ajStrNCmpO", XS_Bio__Emboss_ajStrNCmpO, file);
        newXS("Bio::Emboss::ajStrNew", XS_Bio__Emboss_ajStrNew, file);
        newXS("Bio::Emboss::ajStrNewC", XS_Bio__Emboss_ajStrNewC, file);
        newXS("Bio::Emboss::ajStrNewCIL", XS_Bio__Emboss_ajStrNewCIL, file);
        newXS("Bio::Emboss::ajStrNewCL", XS_Bio__Emboss_ajStrNewCL, file);
        newXS("Bio::Emboss::ajStrNewL", XS_Bio__Emboss_ajStrNewL, file);
        newXS("Bio::Emboss::ajStrNewS", XS_Bio__Emboss_ajStrNewS, file);
        newXS("Bio::Emboss::ajStrPos", XS_Bio__Emboss_ajStrPos, file);
        newXS("Bio::Emboss::ajStrPosI", XS_Bio__Emboss_ajStrPosI, file);
        newXS("Bio::Emboss::ajStrPosII", XS_Bio__Emboss_ajStrPosII, file);
        newXS("Bio::Emboss::ajStrPrefix", XS_Bio__Emboss_ajStrPrefix, file);
        newXS("Bio::Emboss::ajStrPrefixC", XS_Bio__Emboss_ajStrPrefixC, file);
        newXS("Bio::Emboss::ajStrPrefixCC", XS_Bio__Emboss_ajStrPrefixCC, file);
        newXS("Bio::Emboss::ajStrPrefixCase", XS_Bio__Emboss_ajStrPrefixCase, file);
        newXS("Bio::Emboss::ajStrPrefixCaseC", XS_Bio__Emboss_ajStrPrefixCaseC, file);
        newXS("Bio::Emboss::ajStrPrefixCaseCC", XS_Bio__Emboss_ajStrPrefixCaseCC, file);
        newXS("Bio::Emboss::ajStrPrefixCaseCO", XS_Bio__Emboss_ajStrPrefixCaseCO, file);
        newXS("Bio::Emboss::ajStrPrefixCO", XS_Bio__Emboss_ajStrPrefixCO, file);
        newXS("Bio::Emboss::ajStrQuote", XS_Bio__Emboss_ajStrQuote, file);
        newXS("Bio::Emboss::ajStrQuoteStrip", XS_Bio__Emboss_ajStrQuoteStrip, file);
        newXS("Bio::Emboss::ajStrRandom", XS_Bio__Emboss_ajStrRandom, file);
        newXS("Bio::Emboss::ajStrReplace", XS_Bio__Emboss_ajStrReplace, file);
        newXS("Bio::Emboss::ajStrReplaceC", XS_Bio__Emboss_ajStrReplaceC, file);
        newXS("Bio::Emboss::ajStrReplaceK", XS_Bio__Emboss_ajStrReplaceK, file);
        newXS("Bio::Emboss::ajStrRef", XS_Bio__Emboss_ajStrRef, file);
        newXS("Bio::Emboss::ajStrRemoveHtml", XS_Bio__Emboss_ajStrRemoveHtml, file);
        newXS("Bio::Emboss::ajStrRemoveNewline", XS_Bio__Emboss_ajStrRemoveNewline, file);
        newXS("Bio::Emboss::ajStrRev", XS_Bio__Emboss_ajStrRev, file);
        newXS("Bio::Emboss::ajStrRFindC", XS_Bio__Emboss_ajStrRFindC, file);
        newXS("Bio::Emboss::ajStrRoom", XS_Bio__Emboss_ajStrRoom, file);
        newXS("Bio::Emboss::ajStrSet", XS_Bio__Emboss_ajStrSet, file);
        newXS("Bio::Emboss::ajStrSetC", XS_Bio__Emboss_ajStrSetC, file);
        newXS("Bio::Emboss::ajStrSize", XS_Bio__Emboss_ajStrSize, file);
        newXS("Bio::Emboss::ajStrStat", XS_Bio__Emboss_ajStrStat, file);
        newXS("Bio::Emboss::ajStrStr", XS_Bio__Emboss_ajStrStr, file);
        newXS("Bio::Emboss::ajStrSub", XS_Bio__Emboss_ajStrSub, file);
        newXS("Bio::Emboss::ajStrSubstitute", XS_Bio__Emboss_ajStrSubstitute, file);
        newXS("Bio::Emboss::ajStrSubstituteCC", XS_Bio__Emboss_ajStrSubstituteCC, file);
        newXS("Bio::Emboss::ajStrSubstituteKK", XS_Bio__Emboss_ajStrSubstituteKK, file);
        newXS("Bio::Emboss::ajStrSuffix", XS_Bio__Emboss_ajStrSuffix, file);
        newXS("Bio::Emboss::ajStrSuffixC", XS_Bio__Emboss_ajStrSuffixC, file);
        newXS("Bio::Emboss::ajStrSuffixCC", XS_Bio__Emboss_ajStrSuffixCC, file);
        newXS("Bio::Emboss::ajStrSuffixCO", XS_Bio__Emboss_ajStrSuffixCO, file);
        newXS("Bio::Emboss::ajStrToBool", XS_Bio__Emboss_ajStrToBool, file);
        newXS("Bio::Emboss::ajStrToDouble", XS_Bio__Emboss_ajStrToDouble, file);
        newXS("Bio::Emboss::ajStrToFloat", XS_Bio__Emboss_ajStrToFloat, file);
        newXS("Bio::Emboss::ajStrToHex", XS_Bio__Emboss_ajStrToHex, file);
        newXS("Bio::Emboss::ajStrToInt", XS_Bio__Emboss_ajStrToInt, file);
        newXS("Bio::Emboss::ajStrTok", XS_Bio__Emboss_ajStrTok, file);
        newXS("Bio::Emboss::ajStrTokC", XS_Bio__Emboss_ajStrTokC, file);
        newXS("Bio::Emboss::ajStrToken", XS_Bio__Emboss_ajStrToken, file);
        newXS("Bio::Emboss::ajStrTokenAss", XS_Bio__Emboss_ajStrTokenAss, file);
        newXS("Bio::Emboss::ajStrTokenClear", XS_Bio__Emboss_ajStrTokenClear, file);
        newXS("Bio::Emboss::ajStrTokenCount", XS_Bio__Emboss_ajStrTokenCount, file);
        newXS("Bio::Emboss::ajStrTokenCountR", XS_Bio__Emboss_ajStrTokenCountR, file);
        newXS("Bio::Emboss::ajStrTokenInit", XS_Bio__Emboss_ajStrTokenInit, file);
        newXS("Bio::Emboss::ajStrTokenReset", XS_Bio__Emboss_ajStrTokenReset, file);
        newXS("Bio::Emboss::ajStrTokenRest", XS_Bio__Emboss_ajStrTokenRest, file);
        newXS("Bio::Emboss::ajStrTokenTrace", XS_Bio__Emboss_ajStrTokenTrace, file);
        newXS("Bio::Emboss::ajStrToLong", XS_Bio__Emboss_ajStrToLong, file);
        newXS("Bio::Emboss::ajStrToLower", XS_Bio__Emboss_ajStrToLower, file);
        newXS("Bio::Emboss::ajStrToUpper", XS_Bio__Emboss_ajStrToUpper, file);
        newXS("Bio::Emboss::ajStrTrace", XS_Bio__Emboss_ajStrTrace, file);
        newXS("Bio::Emboss::ajStrTraceChars", XS_Bio__Emboss_ajStrTraceChars, file);
        newXS("Bio::Emboss::ajStrTraceT", XS_Bio__Emboss_ajStrTraceT, file);
        newXS("Bio::Emboss::ajStrTrim", XS_Bio__Emboss_ajStrTrim, file);
        newXS("Bio::Emboss::ajStrTrimC", XS_Bio__Emboss_ajStrTrimC, file);
        newXS("Bio::Emboss::ajStrTrimEndC", XS_Bio__Emboss_ajStrTrimEndC, file);
        newXS("Bio::Emboss::ajStrTruncate", XS_Bio__Emboss_ajStrTruncate, file);
        newXS("Bio::Emboss::ajStrWhole", XS_Bio__Emboss_ajStrWhole, file);
        newXS("Bio::Emboss::ajStrWildPrefix", XS_Bio__Emboss_ajStrWildPrefix, file);
        newXS("Bio::Emboss::ajStrWrap", XS_Bio__Emboss_ajStrWrap, file);
        newXS("Bio::Emboss::ajStrWrapLeft", XS_Bio__Emboss_ajStrWrapLeft, file);
        newXS("Bio::Emboss::ajStrYN", XS_Bio__Emboss_ajStrYN, file);
        newXS("Bio::Emboss::ajTrnDel", XS_Bio__Emboss_ajTrnDel, file);
        newXS("Bio::Emboss::ajTrnNew", XS_Bio__Emboss_ajTrnNew, file);
        newXS("Bio::Emboss::ajTrnNewI", XS_Bio__Emboss_ajTrnNewI, file);
        newXS("Bio::Emboss::ajTrnNewC", XS_Bio__Emboss_ajTrnNewC, file);
        newXS("Bio::Emboss::ajTrnReadFile", XS_Bio__Emboss_ajTrnReadFile, file);
        newXS("Bio::Emboss::ajTrnNewPep", XS_Bio__Emboss_ajTrnNewPep, file);
        newXS("Bio::Emboss::ajTrnCodon", XS_Bio__Emboss_ajTrnCodon, file);
        newXS("Bio::Emboss::ajTrnRevCodon", XS_Bio__Emboss_ajTrnRevCodon, file);
        newXS("Bio::Emboss::ajTrnCodonC", XS_Bio__Emboss_ajTrnCodonC, file);
        newXS("Bio::Emboss::ajTrnRevCodonC", XS_Bio__Emboss_ajTrnRevCodonC, file);
        newXS("Bio::Emboss::ajTrnCodonK", XS_Bio__Emboss_ajTrnCodonK, file);
        newXS("Bio::Emboss::ajTrnRevCodonK", XS_Bio__Emboss_ajTrnRevCodonK, file);
        newXS("Bio::Emboss::ajTrnC", XS_Bio__Emboss_ajTrnC, file);
        newXS("Bio::Emboss::ajTrnRevC", XS_Bio__Emboss_ajTrnRevC, file);
        newXS("Bio::Emboss::ajTrnAltRevC", XS_Bio__Emboss_ajTrnAltRevC, file);
        newXS("Bio::Emboss::ajTrnStr", XS_Bio__Emboss_ajTrnStr, file);
        newXS("Bio::Emboss::ajTrnRevStr", XS_Bio__Emboss_ajTrnRevStr, file);
        newXS("Bio::Emboss::ajTrnAltRevStr", XS_Bio__Emboss_ajTrnAltRevStr, file);
        newXS("Bio::Emboss::ajTrnSeq", XS_Bio__Emboss_ajTrnSeq, file);
        newXS("Bio::Emboss::ajTrnRevSeq", XS_Bio__Emboss_ajTrnRevSeq, file);
        newXS("Bio::Emboss::ajTrnAltRevSeq", XS_Bio__Emboss_ajTrnAltRevSeq, file);
        newXS("Bio::Emboss::ajTrnCFrame", XS_Bio__Emboss_ajTrnCFrame, file);
        newXS("Bio::Emboss::ajTrnStrFrame", XS_Bio__Emboss_ajTrnStrFrame, file);
        newXS("Bio::Emboss::ajTrnSeqFrame", XS_Bio__Emboss_ajTrnSeqFrame, file);
        newXS("Bio::Emboss::ajTrnSeqFramePep", XS_Bio__Emboss_ajTrnSeqFramePep, file);
        newXS("Bio::Emboss::ajTrnCDangle", XS_Bio__Emboss_ajTrnCDangle, file);
        newXS("Bio::Emboss::ajTrnStrDangle", XS_Bio__Emboss_ajTrnStrDangle, file);
        newXS("Bio::Emboss::ajTrnGetTitle", XS_Bio__Emboss_ajTrnGetTitle, file);
        newXS("Bio::Emboss::ajTrnGetFileName", XS_Bio__Emboss_ajTrnGetFileName, file);
        newXS("Bio::Emboss::ajTrnStartStop", XS_Bio__Emboss_ajTrnStartStop, file);
        newXS("Bio::Emboss::ajTrnStartStopC", XS_Bio__Emboss_ajTrnStartStopC, file);
        newXS("Bio::Emboss::ajTrnSeqOrig", XS_Bio__Emboss_ajTrnSeqOrig, file);
        newXS("Bio::Emboss::ajExit", XS_Bio__Emboss_ajExit, file);
        newXS("Bio::Emboss::ajExitBad", XS_Bio__Emboss_ajExitBad, file);
        newXS("Bio::Emboss::ajLogInfo", XS_Bio__Emboss_ajLogInfo, file);
        newXS("Bio::Emboss::ajUtilBigendian", XS_Bio__Emboss_ajUtilBigendian, file);
        newXS("Bio::Emboss::ajUtilCatch", XS_Bio__Emboss_ajUtilCatch, file);
        newXS("Bio::Emboss::ajUtilRev2", XS_Bio__Emboss_ajUtilRev2, file);
        newXS("Bio::Emboss::ajUtilRev4", XS_Bio__Emboss_ajUtilRev4, file);
        newXS("Bio::Emboss::ajUtilRev8", XS_Bio__Emboss_ajUtilRev8, file);
        newXS("Bio::Emboss::ajUtilUid", XS_Bio__Emboss_ajUtilUid, file);
        newXS("Bio::Emboss::ajXyzPdbtospNew", XS_Bio__Emboss_ajXyzPdbtospNew, file);
        newXS("Bio::Emboss::ajXyzPdbtospDel", XS_Bio__Emboss_ajXyzPdbtospDel, file);
        newXS("Bio::Emboss::ajXyzPdbtospRead", XS_Bio__Emboss_ajXyzPdbtospRead, file);
        newXS("Bio::Emboss::ajXyzPdbtospReadC", XS_Bio__Emboss_ajXyzPdbtospReadC, file);
        newXS("Bio::Emboss::ajXyzPdbtospReadAll", XS_Bio__Emboss_ajXyzPdbtospReadAll, file);
        newXS("Bio::Emboss::ajXyzPdbtospBinSearch", XS_Bio__Emboss_ajXyzPdbtospBinSearch, file);
        newXS("Bio::Emboss::ajXyzSortPdbtospPdb", XS_Bio__Emboss_ajXyzSortPdbtospPdb, file);
        newXS("Bio::Emboss::ajXyzAtomNew", XS_Bio__Emboss_ajXyzAtomNew, file);
        newXS("Bio::Emboss::ajXyzAtomDel", XS_Bio__Emboss_ajXyzAtomDel, file);
        newXS("Bio::Emboss::ajXyzInContact", XS_Bio__Emboss_ajXyzInContact, file);
        newXS("Bio::Emboss::ajXyzAtomDistance", XS_Bio__Emboss_ajXyzAtomDistance, file);
        newXS("Bio::Emboss::ajXyzChainNew", XS_Bio__Emboss_ajXyzChainNew, file);
        newXS("Bio::Emboss::ajXyzChainDel", XS_Bio__Emboss_ajXyzChainDel, file);
        newXS("Bio::Emboss::ajXyzPdbNew", XS_Bio__Emboss_ajXyzPdbNew, file);
        newXS("Bio::Emboss::ajXyzPdbDel", XS_Bio__Emboss_ajXyzPdbDel, file);
        newXS("Bio::Emboss::ajXyzPdbWriteAll", XS_Bio__Emboss_ajXyzPdbWriteAll, file);
        newXS("Bio::Emboss::ajXyzPdbWriteDomain", XS_Bio__Emboss_ajXyzPdbWriteDomain, file);
        newXS("Bio::Emboss::ajXyzPdbChain", XS_Bio__Emboss_ajXyzPdbChain, file);
        newXS("Bio::Emboss::ajXyzPdbAtomIndexI", XS_Bio__Emboss_ajXyzPdbAtomIndexI, file);
        newXS("Bio::Emboss::ajXyzPdbAtomIndexC", XS_Bio__Emboss_ajXyzPdbAtomIndexC, file);
        newXS("Bio::Emboss::ajXyzPdbAtomIndexICA", XS_Bio__Emboss_ajXyzPdbAtomIndexICA, file);
        newXS("Bio::Emboss::ajXyzPdbAtomIndexCCA", XS_Bio__Emboss_ajXyzPdbAtomIndexCCA, file);
        newXS("Bio::Emboss::ajXyzPdbToSp", XS_Bio__Emboss_ajXyzPdbToSp, file);
        newXS("Bio::Emboss::ajXyzPdbToAcc", XS_Bio__Emboss_ajXyzPdbToAcc, file);
        newXS("Bio::Emboss::ajXyzCpdbRead", XS_Bio__Emboss_ajXyzCpdbRead, file);
        newXS("Bio::Emboss::ajXyzCpdbReadFirstModel", XS_Bio__Emboss_ajXyzCpdbReadFirstModel, file);
        newXS("Bio::Emboss::ajXyzCpdbReadOld", XS_Bio__Emboss_ajXyzCpdbReadOld, file);
        newXS("Bio::Emboss::ajXyzCpdbWriteAll", XS_Bio__Emboss_ajXyzCpdbWriteAll, file);
        newXS("Bio::Emboss::ajXyzCpdbWriteDomain", XS_Bio__Emboss_ajXyzCpdbWriteDomain, file);
        newXS("Bio::Emboss::ajXyzScopNew", XS_Bio__Emboss_ajXyzScopNew, file);
        newXS("Bio::Emboss::ajXyzScopDel", XS_Bio__Emboss_ajXyzScopDel, file);
        newXS("Bio::Emboss::ajXyzScopRead", XS_Bio__Emboss_ajXyzScopRead, file);
        newXS("Bio::Emboss::ajXyzScopReadC", XS_Bio__Emboss_ajXyzScopReadC, file);
        newXS("Bio::Emboss::ajXyzScopReadAll", XS_Bio__Emboss_ajXyzScopReadAll, file);
        newXS("Bio::Emboss::ajXyzScopWrite", XS_Bio__Emboss_ajXyzScopWrite, file);
        newXS("Bio::Emboss::ajXyzScopToPdb", XS_Bio__Emboss_ajXyzScopToPdb, file);
        newXS("Bio::Emboss::ajXyzScopToSp", XS_Bio__Emboss_ajXyzScopToSp, file);
        newXS("Bio::Emboss::ajXyzScopToAcc", XS_Bio__Emboss_ajXyzScopToAcc, file);
        newXS("Bio::Emboss::ajXyzScopToScophit", XS_Bio__Emboss_ajXyzScopToScophit, file);
        newXS("Bio::Emboss::ajXyzScopCompId", XS_Bio__Emboss_ajXyzScopCompId, file);
        newXS("Bio::Emboss::ajXyzScopCopy", XS_Bio__Emboss_ajXyzScopCopy, file);
        newXS("Bio::Emboss::ajXyzScopclaNew", XS_Bio__Emboss_ajXyzScopclaNew, file);
        newXS("Bio::Emboss::ajXyzScopclaDel", XS_Bio__Emboss_ajXyzScopclaDel, file);
        newXS("Bio::Emboss::ajXyzScopclaRead", XS_Bio__Emboss_ajXyzScopclaRead, file);
        newXS("Bio::Emboss::ajXyzScopclaReadC", XS_Bio__Emboss_ajXyzScopclaReadC, file);
        newXS("Bio::Emboss::ajXyzScopdesNew", XS_Bio__Emboss_ajXyzScopdesNew, file);
        newXS("Bio::Emboss::ajXyzScopdesDel", XS_Bio__Emboss_ajXyzScopdesDel, file);
        newXS("Bio::Emboss::ajXyzScopdesRead", XS_Bio__Emboss_ajXyzScopdesRead, file);
        newXS("Bio::Emboss::ajXyzScopdesReadC", XS_Bio__Emboss_ajXyzScopdesReadC, file);
        newXS("Bio::Emboss::ajXyzScophitNew", XS_Bio__Emboss_ajXyzScophitNew, file);
        newXS("Bio::Emboss::ajXyzScophitDel", XS_Bio__Emboss_ajXyzScophitDel, file);
        newXS("Bio::Emboss::ajXyzScophitsToHitlist", XS_Bio__Emboss_ajXyzScophitsToHitlist, file);
        newXS("Bio::Emboss::ajXyzScophitsOverlap", XS_Bio__Emboss_ajXyzScophitsOverlap, file);
        newXS("Bio::Emboss::ajXyzScophitsOverlapAcc", XS_Bio__Emboss_ajXyzScophitsOverlapAcc, file);
        newXS("Bio::Emboss::ajXyzScophitCopy", XS_Bio__Emboss_ajXyzScophitCopy, file);
        newXS("Bio::Emboss::ajXyzScophitListCopy", XS_Bio__Emboss_ajXyzScophitListCopy, file);
        newXS("Bio::Emboss::ajXyzScophitToHit", XS_Bio__Emboss_ajXyzScophitToHit, file);
        newXS("Bio::Emboss::ajXyzScophitCheckTarget", XS_Bio__Emboss_ajXyzScophitCheckTarget, file);
        newXS("Bio::Emboss::ajXyzScophitTarget", XS_Bio__Emboss_ajXyzScophitTarget, file);
        newXS("Bio::Emboss::ajXyzScophitTarget2", XS_Bio__Emboss_ajXyzScophitTarget2, file);
        newXS("Bio::Emboss::ajXyzScophitTargetLowPriority", XS_Bio__Emboss_ajXyzScophitTargetLowPriority, file);
        newXS("Bio::Emboss::ajXyzScophitMergeInsertThis", XS_Bio__Emboss_ajXyzScophitMergeInsertThis, file);
        newXS("Bio::Emboss::ajXyzScophitMergeInsertOther", XS_Bio__Emboss_ajXyzScophitMergeInsertOther, file);
        newXS("Bio::Emboss::ajXyzScophitMerge", XS_Bio__Emboss_ajXyzScophitMerge, file);
        newXS("Bio::Emboss::ajXyzScophitCompSpr", XS_Bio__Emboss_ajXyzScophitCompSpr, file);
        newXS("Bio::Emboss::ajXyzScophitCompStart", XS_Bio__Emboss_ajXyzScophitCompStart, file);
        newXS("Bio::Emboss::ajXyzScophitCompFold", XS_Bio__Emboss_ajXyzScophitCompFold, file);
        newXS("Bio::Emboss::ajXyzScophitCompSfam", XS_Bio__Emboss_ajXyzScophitCompSfam, file);
        newXS("Bio::Emboss::ajXyzScophitCompFam", XS_Bio__Emboss_ajXyzScophitCompFam, file);
        newXS("Bio::Emboss::ajXyzScophitCompAcc", XS_Bio__Emboss_ajXyzScophitCompAcc, file);
        newXS("Bio::Emboss::ajXyzHitNew", XS_Bio__Emboss_ajXyzHitNew, file);
        newXS("Bio::Emboss::ajXyzHitDel", XS_Bio__Emboss_ajXyzHitDel, file);
        newXS("Bio::Emboss::ajXyzHitsOverlap", XS_Bio__Emboss_ajXyzHitsOverlap, file);
        newXS("Bio::Emboss::ajXyzCompScore", XS_Bio__Emboss_ajXyzCompScore, file);
        newXS("Bio::Emboss::ajXyzCompScoreInv", XS_Bio__Emboss_ajXyzCompScoreInv, file);
        newXS("Bio::Emboss::ajXyzCompId", XS_Bio__Emboss_ajXyzCompId, file);
        newXS("Bio::Emboss::ajXyzHitlistNew", XS_Bio__Emboss_ajXyzHitlistNew, file);
        newXS("Bio::Emboss::ajXyzHitlistDel", XS_Bio__Emboss_ajXyzHitlistDel, file);
        newXS("Bio::Emboss::ajXyzHitlistRead", XS_Bio__Emboss_ajXyzHitlistRead, file);
        newXS("Bio::Emboss::ajXyzHitlistReadNode", XS_Bio__Emboss_ajXyzHitlistReadNode, file);
        newXS("Bio::Emboss::ajXyzHitlistReadFam", XS_Bio__Emboss_ajXyzHitlistReadFam, file);
        newXS("Bio::Emboss::ajXyzHitlistReadSfam", XS_Bio__Emboss_ajXyzHitlistReadSfam, file);
        newXS("Bio::Emboss::ajXyzHitlistReadFold", XS_Bio__Emboss_ajXyzHitlistReadFold, file);
        newXS("Bio::Emboss::ajXyzHitlistWrite", XS_Bio__Emboss_ajXyzHitlistWrite, file);
        newXS("Bio::Emboss::ajXyzHitlistToScophits", XS_Bio__Emboss_ajXyzHitlistToScophits, file);
        newXS("Bio::Emboss::ajXyzHitlistClassify", XS_Bio__Emboss_ajXyzHitlistClassify, file);
        newXS("Bio::Emboss::ajXyzHitlistPriorityHigh", XS_Bio__Emboss_ajXyzHitlistPriorityHigh, file);
        newXS("Bio::Emboss::ajXyzHitlistPriorityLow", XS_Bio__Emboss_ajXyzHitlistPriorityLow, file);
        newXS("Bio::Emboss::ajXyzHitlistToThreeScophits", XS_Bio__Emboss_ajXyzHitlistToThreeScophits, file);
        newXS("Bio::Emboss::ajXyzHitlistsWriteFasta", XS_Bio__Emboss_ajXyzHitlistsWriteFasta, file);
        newXS("Bio::Emboss::ajXyzPrintPdbSeqresChain", XS_Bio__Emboss_ajXyzPrintPdbSeqresChain, file);
        newXS("Bio::Emboss::ajXyzPrintPdbSeqresDomain", XS_Bio__Emboss_ajXyzPrintPdbSeqresDomain, file);
        newXS("Bio::Emboss::ajXyzPrintPdbAtomChain", XS_Bio__Emboss_ajXyzPrintPdbAtomChain, file);
        newXS("Bio::Emboss::ajXyzPrintPdbAtomDomain", XS_Bio__Emboss_ajXyzPrintPdbAtomDomain, file);
        newXS("Bio::Emboss::ajXyzPrintPdbHeterogen", XS_Bio__Emboss_ajXyzPrintPdbHeterogen, file);
        newXS("Bio::Emboss::ajXyzPrintPdbText", XS_Bio__Emboss_ajXyzPrintPdbText, file);
        newXS("Bio::Emboss::ajXyzPrintPdbHeader", XS_Bio__Emboss_ajXyzPrintPdbHeader, file);
        newXS("Bio::Emboss::ajXyzPrintPdbHeaderScop", XS_Bio__Emboss_ajXyzPrintPdbHeaderScop, file);
        newXS("Bio::Emboss::ajXyzPrintPdbTitle", XS_Bio__Emboss_ajXyzPrintPdbTitle, file);
        newXS("Bio::Emboss::ajXyzPrintPdbCompnd", XS_Bio__Emboss_ajXyzPrintPdbCompnd, file);
        newXS("Bio::Emboss::ajXyzPrintPdbSource", XS_Bio__Emboss_ajXyzPrintPdbSource, file);
        newXS("Bio::Emboss::ajXyzPrintPdbEmptyRemark", XS_Bio__Emboss_ajXyzPrintPdbEmptyRemark, file);
        newXS("Bio::Emboss::ajXyzPrintPdbResolution", XS_Bio__Emboss_ajXyzPrintPdbResolution, file);
        newXS("Bio::Emboss::ajXyzScopalgRead", XS_Bio__Emboss_ajXyzScopalgRead, file);
        newXS("Bio::Emboss::ajXyzScopalgWrite", XS_Bio__Emboss_ajXyzScopalgWrite, file);
        newXS("Bio::Emboss::ajXyzScopalgWriteClustal", XS_Bio__Emboss_ajXyzScopalgWriteClustal, file);
        newXS("Bio::Emboss::ajXyzScopalgWriteClustal2", XS_Bio__Emboss_ajXyzScopalgWriteClustal2, file);
        newXS("Bio::Emboss::ajXyzScopalgNew", XS_Bio__Emboss_ajXyzScopalgNew, file);
        newXS("Bio::Emboss::ajXyzScopalgDel", XS_Bio__Emboss_ajXyzScopalgDel, file);
        newXS("Bio::Emboss::ajXyzScopalgGetseqs", XS_Bio__Emboss_ajXyzScopalgGetseqs, file);
        newXS("Bio::Emboss::ajXyzCmapNew", XS_Bio__Emboss_ajXyzCmapNew, file);
        newXS("Bio::Emboss::ajXyzCmapDel", XS_Bio__Emboss_ajXyzCmapDel, file);
        newXS("Bio::Emboss::ajXyzCmapRead", XS_Bio__Emboss_ajXyzCmapRead, file);
        newXS("Bio::Emboss::ajXyzCmapReadC", XS_Bio__Emboss_ajXyzCmapReadC, file);
        newXS("Bio::Emboss::ajXyzCmapReadI", XS_Bio__Emboss_ajXyzCmapReadI, file);
        newXS("Bio::Emboss::ajXyzVdwRad", XS_Bio__Emboss_ajXyzVdwRad, file);
        newXS("Bio::Emboss::ajXyzVdwallNew", XS_Bio__Emboss_ajXyzVdwallNew, file);
        newXS("Bio::Emboss::ajXyzVdwallDel", XS_Bio__Emboss_ajXyzVdwallDel, file);
        newXS("Bio::Emboss::ajXyzVdwallRead", XS_Bio__Emboss_ajXyzVdwallRead, file);
        newXS("Bio::Emboss::ajXyzVdwresNew", XS_Bio__Emboss_ajXyzVdwresNew, file);
        newXS("Bio::Emboss::ajXyzVdwresDel", XS_Bio__Emboss_ajXyzVdwresDel, file);
        newXS("Bio::Emboss::ajXyzScorealgNew", XS_Bio__Emboss_ajXyzScorealgNew, file);
        newXS("Bio::Emboss::ajXyzScorealgDel", XS_Bio__Emboss_ajXyzScorealgDel, file);
        newXS("Bio::Emboss::ajXyzSigdatNew", XS_Bio__Emboss_ajXyzSigdatNew, file);
        newXS("Bio::Emboss::ajXyzSigposNew", XS_Bio__Emboss_ajXyzSigposNew, file);
        newXS("Bio::Emboss::ajXyzSigdatDel", XS_Bio__Emboss_ajXyzSigdatDel, file);
        newXS("Bio::Emboss::ajXyzSigposDel", XS_Bio__Emboss_ajXyzSigposDel, file);
        newXS("Bio::Emboss::ajXyzHitidxNew", XS_Bio__Emboss_ajXyzHitidxNew, file);
        newXS("Bio::Emboss::ajXyzHitidxDel", XS_Bio__Emboss_ajXyzHitidxDel, file);
        newXS("Bio::Emboss::ajXyzHitidxBinSearch", XS_Bio__Emboss_ajXyzHitidxBinSearch, file);
        newXS("Bio::Emboss::ajXyzSignatureNew", XS_Bio__Emboss_ajXyzSignatureNew, file);
        newXS("Bio::Emboss::ajXyzSignatureDel", XS_Bio__Emboss_ajXyzSignatureDel, file);
        newXS("Bio::Emboss::ajXyzSignatureRead", XS_Bio__Emboss_ajXyzSignatureRead, file);
        newXS("Bio::Emboss::ajXyzSignatureWrite", XS_Bio__Emboss_ajXyzSignatureWrite, file);
        newXS("Bio::Emboss::ajXyzSignatureCompile", XS_Bio__Emboss_ajXyzSignatureCompile, file);
        newXS("Bio::Emboss::ajXyzSignatureAlignSeq", XS_Bio__Emboss_ajXyzSignatureAlignSeq, file);
        newXS("Bio::Emboss::ajXyzSignatureAlignSeqall", XS_Bio__Emboss_ajXyzSignatureAlignSeqall, file);
#ifdef HAVE_EMBOSS_2_6_0
        newXS("Bio::Emboss::ajXyzSignatureHitsWrite", XS_Bio__Emboss_ajXyzSignatureHitsWrite, file);
#else
        newXS("Bio::Emboss::ajXyzSignatureHitsWrite", XS_Bio__Emboss_ajXyzSignatureHitsWrite, file);
#endif
        newXS("Bio::Emboss::ajXyzSignatureAlignWrite", XS_Bio__Emboss_ajXyzSignatureAlignWrite, file);
        newXS("Bio::Emboss::ajXyzHetentNew", XS_Bio__Emboss_ajXyzHetentNew, file);
        newXS("Bio::Emboss::ajXyzHetentDel", XS_Bio__Emboss_ajXyzHetentDel, file);
        newXS("Bio::Emboss::ajXyzHetNew", XS_Bio__Emboss_ajXyzHetNew, file);
        newXS("Bio::Emboss::ajXyzHetDel", XS_Bio__Emboss_ajXyzHetDel, file);
        newXS("Bio::Emboss::ajXyzHetRawRead", XS_Bio__Emboss_ajXyzHetRawRead, file);
        newXS("Bio::Emboss::ajXyzHetRead", XS_Bio__Emboss_ajXyzHetRead, file);
        newXS("Bio::Emboss::ajXyzHetWrite", XS_Bio__Emboss_ajXyzHetWrite, file);
        newXS("Bio::Emboss::embGrpCompareTwoGnodes", XS_Bio__Emboss_embGrpCompareTwoGnodes, file);
        newXS("Bio::Emboss::embGrpGetProgGroups", XS_Bio__Emboss_embGrpGetProgGroups, file);
        newXS("Bio::Emboss::embGrpGroupsListDel", XS_Bio__Emboss_embGrpGroupsListDel, file);
        newXS("Bio::Emboss::embGrpKeySearchProgs", XS_Bio__Emboss_embGrpKeySearchProgs, file);
        newXS("Bio::Emboss::embGrpKeySearchSeeAlso", XS_Bio__Emboss_embGrpKeySearchSeeAlso, file);
        newXS("Bio::Emboss::embGrpMakeNewGnode", XS_Bio__Emboss_embGrpMakeNewGnode, file);
        newXS("Bio::Emboss::embGrpMakeNewPnode", XS_Bio__Emboss_embGrpMakeNewPnode, file);
        newXS("Bio::Emboss::embGrpOutputGroupsList", XS_Bio__Emboss_embGrpOutputGroupsList, file);
        newXS("Bio::Emboss::embGrpOutputProgsList", XS_Bio__Emboss_embGrpOutputProgsList, file);
        newXS("Bio::Emboss::embGrpSortGroupsList", XS_Bio__Emboss_embGrpSortGroupsList, file);
        newXS("Bio::Emboss::embGrpMakeUnique", XS_Bio__Emboss_embGrpMakeUnique, file);

